diff -pruN 6.0.0-1/CMakeLists.txt 6.3.0-1/CMakeLists.txt
--- 6.0.0-1/CMakeLists.txt	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/CMakeLists.txt	2024-05-31 13:28:20.000000000 +0000
@@ -1,12 +1,12 @@
 cmake_minimum_required(VERSION 3.16)
 
-set(KF_VERSION "6.0.0") # handled by release scripts
-set(KF_DEP_VERSION "6.0.0") # handled by release scripts
+set(KF_VERSION "6.3.0") # handled by release scripts
+set(KF_DEP_VERSION "6.3.0") # handled by release scripts
 project(KSvg VERSION ${KF_VERSION})
 
 # ECM setup
 include(FeatureSummary)
-find_package(ECM 6.0.0  NO_MODULE)
+find_package(ECM 6.3.0  NO_MODULE)
 set_package_properties(ECM PROPERTIES TYPE REQUIRED DESCRIPTION "Extra CMake Modules." URL "https://commits.kde.org/extra-cmake-modules")
 feature_summary(WHAT REQUIRED_PACKAGES_NOT_FOUND FATAL_ON_MISSING_REQUIRED_PACKAGES)
 
diff -pruN 6.0.0-1/autotests/CMakeLists.txt 6.3.0-1/autotests/CMakeLists.txt
--- 6.0.0-1/autotests/CMakeLists.txt	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/autotests/CMakeLists.txt	2024-05-31 13:28:20.000000000 +0000
@@ -23,6 +23,8 @@ MACRO(KSVG_UNIT_TESTS)
                ecm_add_test(${_testname}.cpp
                             LINK_LIBRARIES ${libs}
                             NAME_PREFIX "plasmasvg-")
+               qt_add_resources(${_testname} "images"
+                       FILES "data/background.svgz")
                target_include_directories(${_testname} PRIVATE )
        ENDFOREACH(_testname)
 ENDMACRO(KSVG_UNIT_TESTS)
diff -pruN 6.0.0-1/autotests/data/plasma/desktoptheme/testtheme/colors 6.3.0-1/autotests/data/plasma/desktoptheme/testtheme/colors
--- 6.0.0-1/autotests/data/plasma/desktoptheme/testtheme/colors	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/autotests/data/plasma/desktoptheme/testtheme/colors	2024-05-31 13:28:20.000000000 +0000
@@ -84,7 +84,8 @@ ForegroundInactive=175,176,179
 ForegroundLink=61,174,230
 ForegroundNegative=237,21,21
 ForegroundNeutral=201,206,59
-ForegroundNormal=49,54,59
+#A very glaring red to check those colors are actually applied
+ForegroundNormal=255,54,59
 ForegroundPositive=17,209,22
 ForegroundVisited=61,174,230
 
diff -pruN 6.0.0-1/autotests/framesvgtest.cpp 6.3.0-1/autotests/framesvgtest.cpp
--- 6.0.0-1/autotests/framesvgtest.cpp	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/autotests/framesvgtest.cpp	2024-05-31 13:28:20.000000000 +0000
@@ -5,11 +5,34 @@
 */
 
 #include "framesvgtest.h"
+#include <QDirIterator>
 #include <QStandardPaths>
 
+void copyDirectory(const QString &srcDir, const QString &dstDir)
+{
+    QDir targetDir(dstDir);
+    QDirIterator it(srcDir, QDir::Filters(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot | QDir::Name), QDirIterator::Subdirectories);
+    while (it.hasNext()) {
+        it.next();
+        QString path = it.filePath();
+        QString relDestPath = path.last(it.filePath().length() - srcDir.length() - 1);
+        if (it.fileInfo().isDir()) {
+            QVERIFY(targetDir.mkpath(relDestPath));
+        } else {
+            QVERIFY(QFile::copy(path, dstDir % '/' % relDestPath));
+        }
+    }
+}
+
 void FrameSvgTest::initTestCase()
 {
     QStandardPaths::setTestModeEnabled(true);
+
+    m_themeDir = QDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) % '/' % "plasma");
+    m_themeDir.removeRecursively();
+
+    copyDirectory(QFINDTESTDATA("data/plasma"), m_themeDir.absolutePath());
+
     m_cacheDir = QDir(QStandardPaths::writableLocation(QStandardPaths::CacheLocation));
     m_cacheDir.removeRecursively();
 
@@ -22,6 +45,7 @@ void FrameSvgTest::cleanupTestCase()
 {
     delete m_frameSvg;
 
+    m_themeDir.removeRecursively();
     m_cacheDir.removeRecursively();
 }
 
@@ -74,6 +98,10 @@ void FrameSvgTest::setImageSet()
     frameSvg->framePixmap();
     frameSvg->setImageSet(new KSvg::ImageSet("breeze-dark", {}, this));
     frameSvg->framePixmap();
+
+    frameSvg->setImageSet(new KSvg::ImageSet("testtheme", "plasma/desktoptheme", this));
+    QCOMPARE(frameSvg->color(KSvg::Svg::Text), QColor(255, 54, 59));
+
     delete frameSvg;
 }
 
@@ -87,6 +115,17 @@ void FrameSvgTest::resizeMask()
     QCOMPARE(m_frameSvg->alphaMask().size(), QSize(100, 100));
 }
 
+void FrameSvgTest::loadQrc()
+{
+    KSvg::FrameSvg *frameSvg = new KSvg::FrameSvg;
+    frameSvg->setImageSet(new KSvg::ImageSet("testtheme", "plasma/desktoptheme", this));
+    frameSvg->setImagePath(QStringLiteral("qrc:/data/background.svgz"));
+    QVERIFY(frameSvg->isValid());
+    // An external image is colored as well
+    QCOMPARE(frameSvg->color(KSvg::Svg::Text), QColor(255, 54, 59));
+    delete frameSvg;
+}
+
 QTEST_MAIN(FrameSvgTest)
 
 #include "moc_framesvgtest.cpp"
diff -pruN 6.0.0-1/autotests/framesvgtest.h 6.3.0-1/autotests/framesvgtest.h
--- 6.0.0-1/autotests/framesvgtest.h	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/autotests/framesvgtest.h	2024-05-31 13:28:20.000000000 +0000
@@ -24,9 +24,11 @@ private Q_SLOTS:
     void setImageSet();
     void repaintBlocked();
     void resizeMask();
+    void loadQrc();
 
 private:
     KSvg::FrameSvg *m_frameSvg;
+    QDir m_themeDir;
     QDir m_cacheDir;
 };
 
diff -pruN 6.0.0-1/debian/changelog 6.3.0-1/debian/changelog
--- 6.0.0-1/debian/changelog	2024-05-06 19:24:13.000000000 +0000
+++ 6.3.0-1/debian/changelog	2024-06-09 12:58:32.000000000 +0000
@@ -1,3 +1,18 @@
+kf6-ksvg (6.3.0-1) experimental; urgency=medium
+
+  [ Aurélien COUDERC ]
+  * Drop useless dependency on the ${shlibs:Depends} variable for the -dev
+    package.
+  * Fix Vcs-Git URLs.
+
+  [ Patrick Franz ]
+  * New upstream release (6.3.0).
+  * Bump Standards-Version to 4.7.0 (No changes needed).
+  * Update build-deps and deps with the info from cmake.
+  * Update list of installed files.
+
+ -- Patrick Franz <deltaone@debian.org>  Sun, 09 Jun 2024 14:58:32 +0200
+
 kf6-ksvg (6.0.0-1) experimental; urgency=medium
 
   [ Simon Quigley ]
diff -pruN 6.0.0-1/debian/control 6.3.0-1/debian/control
--- 6.0.0-1/debian/control	2024-05-06 19:24:13.000000000 +0000
+++ 6.3.0-1/debian/control	2024-06-08 09:36:20.000000000 +0000
@@ -11,13 +11,13 @@ Build-Depends: appstream,
                dh-sequence-kf6,
                dh-sequence-pkgkde-symbolshelper,
                doxygen,
-               extra-cmake-modules (>= 6.0.0~),
-               libkf6archive-dev (>= 6.0.0~),
-               libkf6colorscheme-dev (>= 6.0.0~),
-               libkf6config-dev (>= 6.0.0~),
-               libkf6coreaddons-dev (>= 6.0.0~),
-               libkf6guiaddons-dev (>= 6.0.0~),
-               libkirigami-dev (>= 6.0.0~),
+               extra-cmake-modules (>= 6.3.0~),
+               libkf6archive-dev (>= 6.3.0~),
+               libkf6colorscheme-dev (>= 6.3.0~),
+               libkf6config-dev (>= 6.3.0~),
+               libkf6coreaddons-dev (>= 6.3.0~),
+               libkf6guiaddons-dev (>= 6.3.0~),
+               libkirigami-dev (>= 6.3.0~),
                libxkbcommon-dev,
                qt6-base-dev (>= 6.5.0+dfsg~),
                qt6-declarative-dev (>= 6.5.0+dfsg~),
@@ -25,10 +25,10 @@ Build-Depends: appstream,
                qt6-tools-dev (>= 6.5.0~),
                xauth <!nocheck>,
                xvfb <!nocheck>,
-Standards-Version: 4.6.2
+Standards-Version: 4.7.0
 Homepage: https://invent.kde.org/frameworks/ksvg
-Vcs-Browser: https://salsa.debian.org/qt-kde-team/kde/kf6-svg
-Vcs-Git: https://salsa.debian.org/qt-kde-team/kde/kf6-svg.git
+Vcs-Browser: https://salsa.debian.org/qt-kde-team/kde/kf6-ksvg
+Vcs-Git: https://salsa.debian.org/qt-kde-team/kde/kf6-ksvg.git
 Rules-Requires-Root: no
 
 Package: libkf6svg-dev
@@ -37,7 +37,6 @@ Architecture: any
 Depends: libkf6svg6 (= ${binary:Version}),
          qt6-base-dev (>= 6.5.0+dfsg~),
          ${misc:Depends},
-         ${shlibs:Depends},
 Recommends: libkf6svg-doc (= ${source:Version}),
 Description: library for rendering SVG-based themes - development files
  Framework for rendering SVG-based themes with stylesheet re-coloring and
diff -pruN 6.0.0-1/debian/libkf6svg6.install 6.3.0-1/debian/libkf6svg6.install
--- 6.0.0-1/debian/libkf6svg6.install	2024-05-06 19:24:13.000000000 +0000
+++ 6.3.0-1/debian/libkf6svg6.install	2024-06-08 15:45:05.000000000 +0000
@@ -1,3 +1,3 @@
 usr/lib/*/libKF6Svg.so.6
-usr/lib/*/libKF6Svg.so.6.0.0
+usr/lib/*/libKF6Svg.so.6.*
 usr/share/qlogging-categories6/ksvg.categories
diff -pruN 6.0.0-1/debian/upstream/signing-key.asc 6.3.0-1/debian/upstream/signing-key.asc
--- 6.0.0-1/debian/upstream/signing-key.asc	2024-04-13 15:25:21.000000000 +0000
+++ 6.3.0-1/debian/upstream/signing-key.asc	2024-06-07 22:16:50.000000000 +0000
@@ -80,3 +80,24 @@ RUqSlBSJqC4WqZmkB73i16MljvT0+4v2upmud4JK
 oS4=
 =yOFv
 -----END PGP PUBLIC KEY BLOCK-----
+-----BEGIN PGP PUBLIC KEY BLOCK-----
+
+mDMEZZxtxBYJKwYBBAHaRw8BAQdAm/8PHszWuXJwUEeEwowgbi7fIeUDP/r9X14f
+Azm23ay0JU5pY29sYXMgRmVsbGEgPG5pY29sYXMuZmVsbGFAa2RlLm9yZz6IkwQT
+FgoAOxYhBJCpaKyoRTfMJ7meryyN9Yem1KrBBQJlnG8zAhsDBQsJCAcCAiICBhUK
+CQgLAgQWAgMBAh4HAheAAAoJECyN9Yem1KrBeP4BAIKpXwECsL4VtZtg2h6uUCZg
+e6oALUd6LYH6+DAM2cGzAP9nRCB06lOnWPiz3PccQDeGPGTl4fJXM63rXIKvxI8n
+C7QkTmljb2xhcyBGZWxsYSA8bmljb2xhcy5mZWxsYUBnbXguZGU+iJMEExYKADsW
+IQSQqWisqEU3zCe5nq8sjfWHptSqwQUCZZxtxAIbAwULCQgHAgIiAgYVCgkICwIE
+FgIDAQIeBwIXgAAKCRAsjfWHptSqwb/cAQDdwi3Ujltdb58uFEN9Wxvv2a/PmJJr
+v76mHWmXqia0UwD/fpQfF7W6Iv6tEoqE2VQjMdboRqumV2m9lDyB3OPwtg+4MwRl
+nG3EFgkrBgEEAdpHDwEBB0ABCziM0Ive6TFO3hWrLxpYFCti3xUL7fLLdJqIJYHc
+O4h4BBgWCgAgFiEEkKlorKhFN8wnuZ6vLI31h6bUqsEFAmWcbcQCGyAACgkQLI31
+h6bUqsFXfQD9G8xNZ6QbfOeP/ARYPH7xUcc2U4/kPjoP8+R/MRnshPMBANDv6T3y
+BxoNXQRYK65x7ghXOSZcQyBLfVuSQshzf/oBuDgEZZxtxBIKKwYBBAGXVQEFAQEH
+QAOAXtH8j+F4XstbXodRsjUSLSQx3doS6cssY8XiZWZ5AwEIB4h4BBgWCgAgFiEE
+kKlorKhFN8wnuZ6vLI31h6bUqsEFAmWcbcQCGwwACgkQLI31h6bUqsFomwD/Zy41
+I8jssyuukIKsRefmsvFeeMKEJgFp0WuZQaZnKEIBANbtyBSxCOkD+5GYm1cjG6nr
+yPRSi/2EuYie6axT6ZIN
+=Noyp
+-----END PGP PUBLIC KEY BLOCK-----
diff -pruN 6.0.0-1/po/en_GB/libksvg6.po 6.3.0-1/po/en_GB/libksvg6.po
--- 6.0.0-1/po/en_GB/libksvg6.po	1970-01-01 00:00:00.000000000 +0000
+++ 6.3.0-1/po/en_GB/libksvg6.po	2024-05-31 13:28:20.000000000 +0000
@@ -0,0 +1,28 @@
+# Copyright (C) 2024 This file is copyright:
+# This file is distributed under the same license as the ksvg package.
+#
+# SPDX-FileCopyrightText: 2024 Steve Allewell <steve.allewell@gmail.com>
+msgid ""
+msgstr ""
+"Project-Id-Version: ksvg\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2023-07-13 02:10+0000\n"
+"PO-Revision-Date: 2024-05-20 19:22+0100\n"
+"Last-Translator: Steve Allewell <steve.allewell@gmail.com>\n"
+"Language-Team: British English\n"
+"Language: en_GB\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"Plural-Forms: nplurals=2; plural=n != 1;\n"
+"X-Generator: Lokalize 24.02.2\n"
+
+#, kde-format
+msgctxt "NAME OF TRANSLATORS"
+msgid "Your names"
+msgstr "Steve Allewell"
+
+#, kde-format
+msgctxt "EMAIL OF TRANSLATORS"
+msgid "Your emails"
+msgstr "steve.allewell@gmail.com"
diff -pruN 6.0.0-1/po/eo/libksvg6.po 6.3.0-1/po/eo/libksvg6.po
--- 6.0.0-1/po/eo/libksvg6.po	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/po/eo/libksvg6.po	2024-05-31 13:28:20.000000000 +0000
@@ -1,7 +1,7 @@
 # translation of libksvg6.pot to esperanto
 # Copyright (C) 2023 Free Software Foundation, Inc.
 # This file is distributed under the same license as the ksvg package.
-# Oliver Kellogg <okellogg@users.sourceforge.net, 2023.
+# Oliver Kellogg <olivermkellogg@gmail.com, 2023.
 #
 msgid ""
 msgstr ""
@@ -9,7 +9,7 @@ msgstr ""
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
 "POT-Creation-Date: 2023-07-13 02:10+0000\n"
 "PO-Revision-Date: 2023-07-16 06:48+0100\n"
-"Last-Translator: Oliver Kellogg <okellogg@users.sourceforge.net>\n"
+"Last-Translator: Oliver Kellogg <olivermkellogg@gmail.com>\n"
 "Language-Team: Esperanto <kde-i18n-eo@kde.org>\n"
 "Language: eo\n"
 "MIME-Version: 1.0\n"
@@ -25,4 +25,4 @@ msgstr "Oliver Kellogg"
 #, kde-format
 msgctxt "EMAIL OF TRANSLATORS"
 msgid "Your emails"
-msgstr "okellogg@users.sourceforge.net"
+msgstr "olivermkellogg@gmail.com"
diff -pruN 6.0.0-1/po/he/libksvg6.po 6.3.0-1/po/he/libksvg6.po
--- 6.0.0-1/po/he/libksvg6.po	1970-01-01 00:00:00.000000000 +0000
+++ 6.3.0-1/po/he/libksvg6.po	2024-05-31 13:28:20.000000000 +0000
@@ -0,0 +1,29 @@
+# Copyright (C) 2024 This file is copyright:
+# This file is distributed under the same license as the ksvg package.
+#
+# SPDX-FileCopyrightText: 2024 Yaron Shahrabani <sh.yaron@gmail.com>
+msgid ""
+msgstr ""
+"Project-Id-Version: ksvg\n"
+"Report-Msgid-Bugs-To: https://bugs.kde.org\n"
+"POT-Creation-Date: 2023-07-13 02:10+0000\n"
+"PO-Revision-Date: 2024-03-19 07:50+0200\n"
+"Last-Translator: Yaron Shahrabani <sh.yaron@gmail.com>\n"
+"Language-Team: צוות התרגום של KDE ישראל\n"
+"Language: he\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8bit\n"
+"Plural-Forms: nplurals=4; plural=(n == 1) ? 0 : ((n == 2) ? 1 : ((n > 10 && "
+"n % 10 == 0) ? 2 : 3));\n"
+"X-Generator: Lokalize 23.08.5\n"
+
+#, kde-format
+msgctxt "NAME OF TRANSLATORS"
+msgid "Your names"
+msgstr "צוות התרגום של KDE ישראל"
+
+#, kde-format
+msgctxt "EMAIL OF TRANSLATORS"
+msgid "Your emails"
+msgstr "kde-l10n-he@kde.org"
diff -pruN 6.0.0-1/po/pl/libksvg6.po 6.3.0-1/po/pl/libksvg6.po
--- 6.0.0-1/po/pl/libksvg6.po	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/po/pl/libksvg6.po	2024-05-31 13:28:20.000000000 +0000
@@ -16,7 +16,6 @@ msgstr ""
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 "
 "|| n%100>=20) ? 1 : 2);\n"
-"X-Generator: Lokalize 23.04.3\n"
 
 #, kde-format
 msgctxt "NAME OF TRANSLATORS"
diff -pruN 6.0.0-1/po/zh_CN/libksvg6.po 6.3.0-1/po/zh_CN/libksvg6.po
--- 6.0.0-1/po/zh_CN/libksvg6.po	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/po/zh_CN/libksvg6.po	2024-05-31 13:28:20.000000000 +0000
@@ -3,7 +3,7 @@ msgstr ""
 "Project-Id-Version: kdeorg\n"
 "Report-Msgid-Bugs-To: https://bugs.kde.org\n"
 "POT-Creation-Date: 2023-07-13 02:10+0000\n"
-"PO-Revision-Date: 2024-02-05 11:37\n"
+"PO-Revision-Date: 2024-04-22 15:58\n"
 "Last-Translator: \n"
 "Language-Team: Chinese Simplified\n"
 "Language: zh_CN\n"
diff -pruN 6.0.0-1/src/declarativeimports/CMakeLists.txt 6.3.0-1/src/declarativeimports/CMakeLists.txt
--- 6.0.0-1/src/declarativeimports/CMakeLists.txt	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/declarativeimports/CMakeLists.txt	2024-05-31 13:28:20.000000000 +0000
@@ -1,12 +1,11 @@
-ecm_add_qml_module(corebindingsplugin URI "org.kde.ksvg")
+ecm_add_qml_module(corebindingsplugin URI "org.kde.ksvg" VERSION 1.0 DEPENDENCIES QtQuick GENERATE_PLUGIN_SOURCE)
 
 target_sources(corebindingsplugin PRIVATE
-    corebindingsplugin.cpp
     svgitem.cpp
     framesvgitem.cpp
     managedtexturenode.cpp
     imagetexturescache.cpp
-    #quicktheme.cpp
+    types.h
 )
 
 target_link_libraries(corebindingsplugin PRIVATE
diff -pruN 6.0.0-1/src/declarativeimports/corebindingsplugin.cpp 6.3.0-1/src/declarativeimports/corebindingsplugin.cpp
--- 6.0.0-1/src/declarativeimports/corebindingsplugin.cpp	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/declarativeimports/corebindingsplugin.cpp	1970-01-01 00:00:00.000000000 +0000
@@ -1,52 +0,0 @@
-/*
-    SPDX-FileCopyrightText: 2009 Alan Alpert <alan.alpert@nokia.com>
-    SPDX-FileCopyrightText: 2010 Ménard Alexis <menard@kde.org>
-    SPDX-FileCopyrightText: 2010 Marco Martin <mart@kde.org>
-    SPDX-FileCopyrightText: 2013 Sebastian Kügler <sebas@kde.org>
-
-    SPDX-License-Identifier: LGPL-2.0-or-later
-*/
-
-#include "corebindingsplugin.h"
-
-#include <QQmlContext>
-
-#include <ksvg/framesvg.h>
-#include <ksvg/svg.h>
-
-#include <Kirigami/Platform/PlatformTheme>
-
-#include "framesvgitem.h"
-#include "imageset.h"
-#include "svgitem.h"
-
-#include <QDebug>
-#include <QWindow>
-#include <qquickitem.h>
-
-using namespace Qt::Literals::StringLiterals;
-
-void CoreBindingsPlugin::initializeEngine(QQmlEngine *engine, const char *uri)
-{
-    QQmlExtensionPlugin::initializeEngine(engine, uri);
-}
-
-void CoreBindingsPlugin::registerTypes(const char *uri)
-{
-    Q_ASSERT(uri == QByteArray("org.kde.ksvg"));
-
-    qmlRegisterRevision<QQuickItem, 6>(uri, 1, 0);
-    qmlRegisterAnonymousType<Kirigami::Platform::PlatformTheme>(uri, 1);
-    qmlRegisterType<KSvg::Svg>(uri, 1, 0, "Svg");
-    qmlRegisterType<KSvg::FrameSvg>(uri, 1, 0, "FrameSvg");
-    qmlRegisterType<KSvg::SvgItem>(uri, 1, 0, "SvgItem");
-    qmlRegisterType<KSvg::FrameSvgItem>(uri, 1, 0, "FrameSvgItem");
-    qmlRegisterUncreatableType<KSvg::FrameSvgItemMargins>(uri, 1, 0, "FrameSvgItemMargins", u"FrameSvgItemMargins are read-only properties of FrameSvgItem"_s);
-    qmlRegisterType<KSvg::ImageSet>(uri, 1, 0, "ImageSet");
-
-    qmlRegisterSingletonType<KSvg::ImageSet>(uri, 1, 0, "ImageSet", [](QQmlEngine *, QJSEngine *) {
-        return new KSvg::ImageSet;
-    });
-}
-
-#include "moc_corebindingsplugin.cpp"
diff -pruN 6.0.0-1/src/declarativeimports/corebindingsplugin.h 6.3.0-1/src/declarativeimports/corebindingsplugin.h
--- 6.0.0-1/src/declarativeimports/corebindingsplugin.h	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/declarativeimports/corebindingsplugin.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,26 +0,0 @@
-/*
-    SPDX-FileCopyrightText: 2009 Alan Alpert <alan.alpert@nokia.com>
-    SPDX-FileCopyrightText: 2010 Ménard Alexis <menard@kde.org>
-    SPDX-FileCopyrightText: 2010 Marco Martin <mart@kde.org>
-    SPDX-FileCopyrightText: 2013 Sebastian Kügler <sebas@kde.org>
-
-    SPDX-License-Identifier: LGPL-2.0-or-later
-*/
-
-#ifndef COREBINDINGSPLUGIN_H
-#define COREBINDINGSPLUGIN_H
-
-#include <QQmlEngine>
-#include <QQmlExtensionPlugin>
-
-class CoreBindingsPlugin : public QQmlExtensionPlugin
-{
-    Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
-
-public:
-    void initializeEngine(QQmlEngine *engine, const char *uri) override;
-    void registerTypes(const char *uri) override;
-};
-
-#endif
diff -pruN 6.0.0-1/src/declarativeimports/framesvgitem.cpp 6.3.0-1/src/declarativeimports/framesvgitem.cpp
--- 6.0.0-1/src/declarativeimports/framesvgitem.cpp	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/declarativeimports/framesvgitem.cpp	2024-05-31 13:28:20.000000000 +0000
@@ -122,7 +122,7 @@ public:
 
     void reposition(const QRect &frameGeometry, QSize &fullSize)
     {
-        QRect nodeRect = FrameSvgHelpers::sectionRect(m_border, frameGeometry, fullSize);
+        QRectF nodeRect = FrameSvgHelpers::sectionRect(m_border, frameGeometry, fullSize);
 
         // ensure we're not passing a weird rectangle to updateTexturedRectGeometry
         if (!nodeRect.isValid() || nodeRect.isEmpty()) {
@@ -152,7 +152,7 @@ public:
             QString elementId = prefix + FrameSvgHelpers::borderToElementId(m_border);
 
             // re-render the SVG at new size
-            updateTexture(nodeRect.size(), elementId);
+            updateTexture(nodeRect.size().toSize(), elementId);
             textureRect = texture()->normalizedTextureSubRect();
         } else if (texture()) { // for fast stretch.
             textureRect = texture()->normalizedTextureSubRect();
@@ -313,7 +313,7 @@ public:
         const QList<qreal> oldMarginsBefore = m_oldMargins;
         m_oldMargins = m_marginsObject ? m_marginsObject->margins() : QList<qreal>();
 
-        if (oldMarginsBefore != m_oldMargins) {
+        if (m_marginsObject && oldMarginsBefore != m_oldMargins) {
             m_marginsObject->update();
         }
     }
@@ -726,10 +726,7 @@ void FrameSvgItem::componentComplete()
 
 void FrameSvgItem::updateDevicePixelRatio()
 {
-    // devicepixelratio is always set integer in the svg, so needs at least 192dpi to double up.
-    //(it needs to be integer to have lines contained inside a svg piece to keep being pixel aligned)
-    const auto newDevicePixelRatio = std::max<qreal>(1.0, floor(window() ? window()->devicePixelRatio() : qApp->devicePixelRatio()));
-
+    const auto newDevicePixelRatio = std::max<qreal>(1.0, (window() ? window()->devicePixelRatio() : qApp->devicePixelRatio()));
     if (newDevicePixelRatio != m_frameSvg->devicePixelRatio()) {
         m_frameSvg->setDevicePixelRatio(newDevicePixelRatio);
         m_textureChanged = true;
diff -pruN 6.0.0-1/src/declarativeimports/framesvgitem.h 6.3.0-1/src/declarativeimports/framesvgitem.h
--- 6.0.0-1/src/declarativeimports/framesvgitem.h	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/declarativeimports/framesvgitem.h	2024-05-31 13:28:20.000000000 +0000
@@ -12,6 +12,8 @@
 
 #include <KSvg/FrameSvg>
 
+#include <qqmlregistration.h>
+
 namespace Kirigami
 {
 namespace Platform
@@ -32,6 +34,8 @@ class FrameSvg;
 class FrameSvgItemMargins : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_UNCREATABLE("FrameSvgItemMargins are read-only properties of FrameSvgItem")
 
     /**
      * @brief This property holds the left margin's width in pixels.
@@ -108,6 +112,7 @@ private:
 class FrameSvgItem : public QQuickItem
 {
     Q_OBJECT
+    QML_ELEMENT
     Q_INTERFACES(QQmlParserStatus)
 
     /**
@@ -145,7 +150,7 @@ class FrameSvgItem : public QQuickItem
      * @see FrameSvgItemMargins
      * @property FrameSvgItemMargins margins
      */
-    Q_PROPERTY(FrameSvgItemMargins *margins READ margins CONSTANT)
+    Q_PROPERTY(KSvg::FrameSvgItemMargins *margins READ margins CONSTANT)
 
     /**
      * @brief This property holds the fixed margins of the frame which are used
@@ -154,7 +159,7 @@ class FrameSvgItem : public QQuickItem
      * @see FrameSvgItemMargins
      * @property FrameSvgItemMargins margins
      */
-    Q_PROPERTY(FrameSvgItemMargins *fixedMargins READ fixedMargins CONSTANT)
+    Q_PROPERTY(KSvg::FrameSvgItemMargins *fixedMargins READ fixedMargins CONSTANT)
 
     /**
      * @brief This property holds the frame's inset.
@@ -164,7 +169,7 @@ class FrameSvgItem : public QQuickItem
      * @since 5.77
      * @property FrameSvgItemMargins margins
      */
-    Q_PROPERTY(FrameSvgItemMargins *inset READ inset CONSTANT)
+    Q_PROPERTY(KSvg::FrameSvgItemMargins *inset READ inset CONSTANT)
 
     /**
      * @brief This property specifies which borders are shown.
diff -pruN 6.0.0-1/src/declarativeimports/plugins.qmltypes 6.3.0-1/src/declarativeimports/plugins.qmltypes
--- 6.0.0-1/src/declarativeimports/plugins.qmltypes	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/declarativeimports/plugins.qmltypes	1970-01-01 00:00:00.000000000 +0000
@@ -1,1586 +0,0 @@
-import QtQuick.tooling 1.2
-
-// This file describes the plugin-supplied types contained in the library.
-// It is used for QML tooling purposes only.
-//
-// This file was auto-generated by:
-// 'qmlplugindump-qt5 -nonrelocatable org.kde.plasma.core 2.0 /usr/lib64/qt5/qml/'
-
-Module {
-    dependencies: [
-        "QtGraphicalEffects 1.12",
-        "QtQml 2.7",
-        "QtQml.Models 2.2",
-        "QtQml.WorkerScript 2.15",
-        "QtQuick 2.9",
-        "QtQuick.Controls 2.5",
-        "QtQuick.Layouts 1.4",
-        "QtQuick.Templates 2.5",
-        "QtQuick.Window 2.6",
-        "org.kde.kconfig 1.0",
-        "org.kde.kirigami 2.20",
-        "org.kde.kirigami.templates 2.2",
-        "org.kde.kquickcontrolsaddons 2.0",
-        "org.kde.plasma.components 3.0",
-        "org.kde.plasma.extras 2.0",
-        "org.kde.sonnet 1.0"
-    ]
-    Component {
-        name: "ColorScope"
-        defaultProperty: "data"
-        prototype: "QQuickItem"
-        exports: ["org.kde.plasma.core/ColorScope 2.0"]
-        exportMetaObjectRevisions: [0]
-        Property { name: "colorGroup"; type: "KSvg::Theme::ColorGroup" }
-        Property { name: "textColor"; type: "QColor"; isReadonly: true }
-        Property { name: "highlightColor"; type: "QColor"; isReadonly: true }
-        Property { name: "highlightedTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "backgroundColor"; type: "QColor"; isReadonly: true }
-        Property { name: "positiveTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "neutralTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "negativeTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "disabledTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "inherit"; type: "bool" }
-        Signal { name: "colorsChanged" }
-    }
-    Component {
-        name: "IconItem"
-        defaultProperty: "data"
-        prototype: "QQuickItem"
-        exports: ["org.kde.plasma.core/IconItem 2.0"]
-        exportMetaObjectRevisions: [0]
-        Property { name: "source"; type: "QVariant" }
-        Property { name: "colorGroup"; type: "KSvg::Theme::ColorGroup" }
-        Property { name: "overlays"; type: "QStringList" }
-        Property { name: "active"; type: "bool" }
-        Property { name: "status"; type: "KSvg::Svg::Status" }
-        Property { name: "animated"; type: "bool" }
-        Property { name: "usesPlasmaTheme"; type: "bool" }
-        Property { name: "roundToIconSize"; type: "bool" }
-        Property { name: "valid"; type: "bool"; isReadonly: true }
-        Property { name: "paintedWidth"; type: "int"; isReadonly: true }
-        Property { name: "paintedHeight"; type: "int"; isReadonly: true }
-        Property { name: "implicitHeight"; type: "int" }
-        Property { name: "implicitWidth"; type: "int" }
-        Signal { name: "paintedSizeChanged" }
-        Signal { name: "implicitHeightChanged2" }
-        Signal { name: "implicitWidthChanged2" }
-    }
-    Component {
-        name: "KSvg::DataModel"
-        prototype: "QAbstractItemModel"
-        exports: ["org.kde.plasma.core/DataModel 2.0"]
-        exportMetaObjectRevisions: [0]
-        Property { name: "dataSource"; type: "QObject"; isPointer: true }
-        Property { name: "keyRoleFilter"; type: "string" }
-        Property { name: "sourceFilter"; type: "string" }
-        Property { name: "count"; type: "int"; isReadonly: true }
-        Signal {
-            name: "sourceModelChanged"
-            Parameter { type: "QObject"; isPointer: true }
-        }
-        Signal {
-            name: "filterRegExpChanged"
-            Parameter { type: "string" }
-        }
-        Method {
-            name: "get"
-            type: "QVariantMap"
-            Parameter { name: "i"; type: "int" }
-        }
-    }
-    Component {
-        name: "KSvg::FrameSvg"
-        prototype: "KSvg::Svg"
-        exports: ["org.kde.plasma.core/FrameSvg 2.0"]
-        exportMetaObjectRevisions: [0]
-        Enum {
-            name: "EnabledBorders"
-            values: {
-                "NoBorder": 0,
-                "TopBorder": 1,
-                "BottomBorder": 2,
-                "LeftBorder": 4,
-                "RightBorder": 8,
-                "AllBorders": 15
-            }
-        }
-        Property { name: "enabledBorders"; type: "EnabledBorders" }
-        Method {
-            name: "setImagePath"
-            Parameter { name: "path"; type: "string" }
-        }
-        Method {
-            name: "resizeFrame"
-            Parameter { name: "size"; type: "QSizeF" }
-        }
-        Method { name: "frameSize"; type: "QSizeF" }
-        Method {
-            name: "marginSize"
-            type: "double"
-            Parameter { name: "edge"; type: "KSvg::Types::MarginEdge" }
-        }
-        Method {
-            name: "getMargins"
-            Parameter { name: "left"; type: "qreal&" }
-            Parameter { name: "top"; type: "qreal&" }
-            Parameter { name: "right"; type: "qreal&" }
-            Parameter { name: "bottom"; type: "qreal&" }
-        }
-        Method {
-            name: "fixedMarginSize"
-            type: "double"
-            Parameter { name: "edge"; type: "KSvg::Types::MarginEdge" }
-        }
-        Method {
-            name: "getFixedMargins"
-            Parameter { name: "left"; type: "qreal&" }
-            Parameter { name: "top"; type: "qreal&" }
-            Parameter { name: "right"; type: "qreal&" }
-            Parameter { name: "bottom"; type: "qreal&" }
-        }
-        Method {
-            name: "insetSize"
-            type: "double"
-            Parameter { name: "edge"; type: "KSvg::Types::MarginEdge" }
-        }
-        Method {
-            name: "getInset"
-            Parameter { name: "left"; type: "qreal&" }
-            Parameter { name: "top"; type: "qreal&" }
-            Parameter { name: "right"; type: "qreal&" }
-            Parameter { name: "bottom"; type: "qreal&" }
-        }
-        Method { name: "contentsRect"; type: "QRectF" }
-        Method {
-            name: "setElementPrefix"
-            Parameter { name: "location"; type: "KSvg::Types::Location" }
-        }
-        Method {
-            name: "setElementPrefix"
-            Parameter { name: "prefix"; type: "string" }
-        }
-        Method {
-            name: "hasElementPrefix"
-            type: "bool"
-            Parameter { name: "prefix"; type: "string" }
-        }
-        Method {
-            name: "hasElementPrefix"
-            type: "bool"
-            Parameter { name: "location"; type: "KSvg::Types::Location" }
-        }
-        Method { name: "prefix"; type: "string" }
-        Method { name: "mask"; type: "QRegion" }
-        Method {
-            name: "setCacheAllRenderedFrames"
-            Parameter { name: "cache"; type: "bool" }
-        }
-        Method { name: "cacheAllRenderedFrames"; type: "bool" }
-        Method { name: "clearCache" }
-        Method { name: "framePixmap"; type: "QPixmap" }
-        Method {
-            name: "paintFrame"
-            Parameter { name: "painter"; type: "QPainter"; isPointer: true }
-            Parameter { name: "target"; type: "QRectF" }
-            Parameter { name: "source"; type: "QRectF" }
-        }
-        Method {
-            name: "paintFrame"
-            Parameter { name: "painter"; type: "QPainter"; isPointer: true }
-            Parameter { name: "target"; type: "QRectF" }
-        }
-        Method {
-            name: "paintFrame"
-            Parameter { name: "painter"; type: "QPainter"; isPointer: true }
-            Parameter { name: "pos"; type: "QPointF" }
-        }
-        Method {
-            name: "paintFrame"
-            Parameter { name: "painter"; type: "QPainter"; isPointer: true }
-        }
-    }
-    Component {
-        name: "KSvg::FrameSvgItem"
-        defaultProperty: "data"
-        prototype: "QQuickItem"
-        exports: ["org.kde.plasma.core/FrameSvgItem 2.0"]
-        exportMetaObjectRevisions: [0]
-        Property { name: "imagePath"; type: "string" }
-        Property { name: "prefix"; type: "QVariant" }
-        Property { name: "usedPrefix"; type: "string"; isReadonly: true }
-        Property { name: "margins"; type: "QObject"; isReadonly: true; isPointer: true }
-        Property { name: "fixedMargins"; type: "QObject"; isReadonly: true; isPointer: true }
-        Property { name: "inset"; type: "QObject"; isReadonly: true; isPointer: true }
-        Property { name: "enabledBorders"; type: "KSvg::FrameSvg::EnabledBorders" }
-        Property { name: "fromCurrentTheme"; type: "bool"; isReadonly: true }
-        Property { name: "colorGroup"; type: "KSvg::Theme::ColorGroup" }
-        Property { name: "status"; type: "KSvg::Svg::Status" }
-        Property { name: "mask"; type: "QRegion"; isReadonly: true }
-        Signal { name: "repaintNeeded" }
-        Method {
-            name: "hasElementPrefix"
-            type: "bool"
-            Parameter { name: "prefix"; type: "string" }
-        }
-    }
-    Component {
-        name: "KSvg::FrameSvgItemMargins"
-        prototype: "QObject"
-        Property { name: "left"; type: "double"; isReadonly: true }
-        Property { name: "top"; type: "double"; isReadonly: true }
-        Property { name: "right"; type: "double"; isReadonly: true }
-        Property { name: "bottom"; type: "double"; isReadonly: true }
-        Property { name: "horizontal"; type: "double"; isReadonly: true }
-        Property { name: "vertical"; type: "double"; isReadonly: true }
-        Signal { name: "marginsChanged" }
-        Method { name: "update" }
-    }
-    Component {
-        name: "KSvg::QuickTheme"
-        prototype: "KSvg::Theme"
-        exports: ["org.kde.plasma.core/Theme 2.0"]
-        isCreatable: false
-        isSingleton: true
-        exportMetaObjectRevisions: [0]
-        Property { name: "textColor"; type: "QColor"; isReadonly: true }
-        Property { name: "highlightColor"; type: "QColor"; isReadonly: true }
-        Property { name: "highlightedTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "backgroundColor"; type: "QColor"; isReadonly: true }
-        Property { name: "linkColor"; type: "QColor"; isReadonly: true }
-        Property { name: "visitedLinkColor"; type: "QColor"; isReadonly: true }
-        Property { name: "positiveTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "neutralTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "negativeTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "disabledTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "buttonTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "buttonBackgroundColor"; type: "QColor"; isReadonly: true }
-        Property { name: "buttonHoverColor"; type: "QColor"; isReadonly: true }
-        Property { name: "buttonFocusColor"; type: "QColor"; isReadonly: true }
-        Property { name: "buttonHighlightedTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "buttonPositiveTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "buttonNeutralTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "buttonNegativeTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "viewTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "viewBackgroundColor"; type: "QColor"; isReadonly: true }
-        Property { name: "viewHoverColor"; type: "QColor"; isReadonly: true }
-        Property { name: "viewFocusColor"; type: "QColor"; isReadonly: true }
-        Property { name: "viewHighlightedTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "viewPositiveTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "viewNeutralTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "viewNegativeTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "complementaryTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "complementaryBackgroundColor"; type: "QColor"; isReadonly: true }
-        Property { name: "complementaryHoverColor"; type: "QColor"; isReadonly: true }
-        Property { name: "complementaryFocusColor"; type: "QColor"; isReadonly: true }
-        Property { name: "complementaryHighlightedTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "complementaryPositiveTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "complementaryNeutralTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "complementaryNegativeTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "headerTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "headerBackgroundColor"; type: "QColor"; isReadonly: true }
-        Property { name: "headerHoverColor"; type: "QColor"; isReadonly: true }
-        Property { name: "headerFocusColor"; type: "QColor"; isReadonly: true }
-        Property { name: "headerHighlightedTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "headerPositiveTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "headerNeutralTextColor"; type: "QColor"; isReadonly: true }
-        Property { name: "headerNegativeTextColor"; type: "QColor"; isReadonly: true }
-        Signal { name: "themeChangedProxy" }
-    }
-    Component {
-        name: "KSvg::SortFilterModel"
-        prototype: "QSortFilterProxyModel"
-        exports: [
-            "org.kde.plasma.core/SortFilterModel 2.0",
-            "org.kde.plasma.core/SortFilterModel 2.1"
-        ]
-        exportMetaObjectRevisions: [0, 1]
-        Property { name: "sourceModel"; type: "QAbstractItemModel"; isPointer: true }
-        Property { name: "filterRegExp"; type: "string" }
-        Property { name: "filterString"; revision: 1; type: "string" }
-        Property { name: "filterCallback"; revision: 1; type: "QJSValue" }
-        Property { name: "filterRole"; type: "string" }
-        Property { name: "sortRole"; type: "string" }
-        Property { name: "sortOrder"; type: "Qt::SortOrder" }
-        Property { name: "sortColumn"; type: "int" }
-        Property { name: "count"; type: "int"; isReadonly: true }
-        Signal {
-            name: "sourceModelChanged"
-            Parameter { type: "QObject"; isPointer: true }
-        }
-        Signal {
-            name: "filterRegExpChanged"
-            Parameter { type: "string" }
-        }
-        Signal {
-            name: "filterStringChanged"
-            revision: 1
-            Parameter { type: "string" }
-        }
-        Signal {
-            name: "filterCallbackChanged"
-            revision: 1
-            Parameter { type: "QJSValue" }
-        }
-        Method {
-            name: "get"
-            type: "QVariantMap"
-            Parameter { name: "i"; type: "int" }
-        }
-        Method {
-            name: "mapRowToSource"
-            type: "int"
-            Parameter { name: "i"; type: "int" }
-        }
-        Method {
-            name: "mapRowFromSource"
-            type: "int"
-            Parameter { name: "i"; type: "int" }
-        }
-    }
-    Component {
-        name: "KSvg::Svg"
-        prototype: "QObject"
-        exports: ["org.kde.plasma.core/Svg 2.0"]
-        exportMetaObjectRevisions: [0]
-        Enum {
-            name: "Status"
-            values: {
-                "Normal": 0,
-                "Selected": 1,
-                "Inactive": 2
-            }
-        }
-        Property { name: "size"; type: "QSize" }
-        Property { name: "multipleImages"; type: "bool" }
-        Property { name: "imagePath"; type: "string" }
-        Property { name: "usingRenderingCache"; type: "bool" }
-        Property { name: "fromCurrentTheme"; type: "bool"; isReadonly: true }
-        Property { name: "colorGroup"; type: "KSvg::Theme::ColorGroup" }
-        Property { name: "status"; type: "KSvg::Svg::Status" }
-        Signal { name: "repaintNeeded" }
-        Signal { name: "colorHintChanged" }
-        Signal {
-            name: "fromCurrentThemeChanged"
-            Parameter { name: "fromCurrentTheme"; type: "bool" }
-        }
-        Signal {
-            name: "statusChanged"
-            Parameter { name: "status"; type: "KSvg::Svg::Status" }
-        }
-        Method {
-            name: "pixmap"
-            type: "QPixmap"
-            Parameter { name: "elementID"; type: "string" }
-        }
-        Method { name: "pixmap"; type: "QPixmap" }
-        Method {
-            name: "image"
-            type: "QImage"
-            Parameter { name: "size"; type: "QSize" }
-            Parameter { name: "elementID"; type: "string" }
-        }
-        Method {
-            name: "image"
-            type: "QImage"
-            Parameter { name: "size"; type: "QSize" }
-        }
-        Method {
-            name: "paint"
-            Parameter { name: "painter"; type: "QPainter"; isPointer: true }
-            Parameter { name: "point"; type: "QPointF" }
-            Parameter { name: "elementID"; type: "string" }
-        }
-        Method {
-            name: "paint"
-            Parameter { name: "painter"; type: "QPainter"; isPointer: true }
-            Parameter { name: "point"; type: "QPointF" }
-        }
-        Method {
-            name: "paint"
-            Parameter { name: "painter"; type: "QPainter"; isPointer: true }
-            Parameter { name: "x"; type: "int" }
-            Parameter { name: "y"; type: "int" }
-            Parameter { name: "elementID"; type: "string" }
-        }
-        Method {
-            name: "paint"
-            Parameter { name: "painter"; type: "QPainter"; isPointer: true }
-            Parameter { name: "x"; type: "int" }
-            Parameter { name: "y"; type: "int" }
-        }
-        Method {
-            name: "paint"
-            Parameter { name: "painter"; type: "QPainter"; isPointer: true }
-            Parameter { name: "rect"; type: "QRectF" }
-            Parameter { name: "elementID"; type: "string" }
-        }
-        Method {
-            name: "paint"
-            Parameter { name: "painter"; type: "QPainter"; isPointer: true }
-            Parameter { name: "rect"; type: "QRectF" }
-        }
-        Method {
-            name: "paint"
-            Parameter { name: "painter"; type: "QPainter"; isPointer: true }
-            Parameter { name: "x"; type: "int" }
-            Parameter { name: "y"; type: "int" }
-            Parameter { name: "width"; type: "int" }
-            Parameter { name: "height"; type: "int" }
-            Parameter { name: "elementID"; type: "string" }
-        }
-        Method {
-            name: "paint"
-            Parameter { name: "painter"; type: "QPainter"; isPointer: true }
-            Parameter { name: "x"; type: "int" }
-            Parameter { name: "y"; type: "int" }
-            Parameter { name: "width"; type: "int" }
-            Parameter { name: "height"; type: "int" }
-        }
-        Method {
-            name: "resize"
-            Parameter { name: "width"; type: "double" }
-            Parameter { name: "height"; type: "double" }
-        }
-        Method {
-            name: "resize"
-            Parameter { name: "size"; type: "QSizeF" }
-        }
-        Method { name: "resize" }
-        Method {
-            name: "elementSize"
-            type: "QSize"
-            Parameter { name: "elementId"; type: "string" }
-        }
-        Method {
-            name: "elementRect"
-            type: "QRectF"
-            Parameter { name: "elementId"; type: "string" }
-        }
-        Method {
-            name: "hasElement"
-            type: "bool"
-            Parameter { name: "elementId"; type: "string" }
-        }
-        Method { name: "isValid"; type: "bool" }
-    }
-    Component {
-        name: "KSvg::SvgItem"
-        defaultProperty: "data"
-        prototype: "QQuickItem"
-        exports: ["org.kde.plasma.core/SvgItem 2.0"]
-        exportMetaObjectRevisions: [0]
-        Property { name: "elementId"; type: "string" }
-        Property { name: "svg"; type: "KSvg::Svg"; isPointer: true }
-        Property { name: "naturalSize"; type: "QSizeF"; isReadonly: true }
-    }
-    Component {
-        name: "KSvg::Theme"
-        prototype: "QObject"
-        Enum {
-            name: "ColorGroup"
-            values: {
-                "NormalColorGroup": 0,
-                "ButtonColorGroup": 1,
-                "ViewColorGroup": 2,
-                "ComplementaryColorGroup": 3,
-                "HeaderColorGroup": 4,
-                "ToolTipColorGroup": 5
-            }
-        }
-        Property { name: "themeName"; type: "string"; isReadonly: true }
-        Property { name: "useGlobalSettings"; type: "bool"; isReadonly: true }
-        Property { name: "wallpaperPath"; type: "string"; isReadonly: true }
-        Property { name: "defaultFont"; type: "QFont"; isReadonly: true }
-        Property { name: "smallestFont"; type: "QFont"; isReadonly: true }
-        Property { name: "styleSheet"; type: "string"; isReadonly: true }
-        Property { name: "palette"; type: "QPalette"; isReadonly: true }
-        Signal { name: "themeChanged" }
-        Method {
-            name: "wallpaperPathForSize"
-            type: "string"
-            Parameter { name: "width"; type: "int" }
-            Parameter { name: "height"; type: "int" }
-        }
-        Method {
-            name: "wallpaperPathForSize"
-            type: "string"
-            Parameter { name: "width"; type: "int" }
-        }
-        Method { name: "wallpaperPathForSize"; type: "string" }
-        Method {
-            name: "mSize"
-            type: "QSizeF"
-            Parameter { name: "font"; type: "QFont" }
-        }
-        Method { name: "mSize"; type: "QSizeF" }
-    }
-    Component {
-        name: "KSvg::Types"
-        prototype: "QObject"
-        exports: ["org.kde.plasma.core/Types 2.0"]
-        isCreatable: false
-        exportMetaObjectRevisions: [0]
-        Enum {
-            name: "Constraint"
-            values: {
-                "NoConstraint": 0,
-                "FormFactorConstraint": 1,
-                "LocationConstraint": 2,
-                "ScreenConstraint": 4,
-                "ImmutableConstraint": 8,
-                "StartupCompletedConstraint": 16,
-                "UiReadyConstraint": 32,
-                "AllConstraints": 15
-            }
-        }
-        Enum {
-            name: "ConstraintFlags"
-            values: {
-                "NoHint": 0,
-                "CanFillArea": 1,
-                "MarginAreasSeparator": 3
-            }
-        }
-        Enum {
-            name: "FormFactor"
-            values: {
-                "Planar": 0,
-                "MediaCenter": 1,
-                "Horizontal": 2,
-                "Vertical": 3,
-                "Application": 4
-            }
-        }
-        Enum {
-            name: "ContainmentDisplayHint"
-            values: {
-                "NoContainmentDisplayHint": 0,
-                "ContainmentDrawsPlasmoidHeading": 1,
-                "ContainmentForcesSquarePlasmoids": 2,
-                "DesktopFullyCovered": 4
-            }
-        }
-        Enum {
-            name: "ContainmentDisplayHints"
-            values: {
-                "NoContainmentDisplayHint": 0,
-                "ContainmentDrawsPlasmoidHeading": 1,
-                "ContainmentForcesSquarePlasmoids": 2,
-                "DesktopFullyCovered": 4
-            }
-        }
-        Enum {
-            name: "ContainmentType"
-            values: {
-                "NoContainmentType": -1,
-                "DesktopContainment": 0,
-                "PanelContainment": 1,
-                "CustomContainment": 127,
-                "CustomPanelContainment": 128,
-                "CustomEmbeddedContainment": 129
-            }
-        }
-        Enum {
-            name: "ActionType"
-            values: {
-                "AddAction": 0,
-                "ConfigureAction": 100,
-                "ControlAction": 200,
-                "MiscAction": 300,
-                "DestructiveAction": 400,
-                "UserAction": 1400
-            }
-        }
-        Enum {
-            name: "Direction"
-            values: {
-                "Down": 0,
-                "Up": 1,
-                "Left": 2,
-                "Right": 3
-            }
-        }
-        Enum {
-            name: "Location"
-            values: {
-                "Floating": 0,
-                "Desktop": 1,
-                "FullScreen": 2,
-                "TopEdge": 3,
-                "BottomEdge": 4,
-                "LeftEdge": 5,
-                "RightEdge": 6
-            }
-        }
-        Enum {
-            name: "Position"
-            values: {
-                "LeftPositioned": 0,
-                "RightPositioned": 1,
-                "TopPositioned": 2,
-                "BottomPositioned": 3,
-                "CenterPositioned": 4
-            }
-        }
-        Enum {
-            name: "PopupPlacement"
-            values: {
-                "FloatingPopup": 0,
-                "TopPosedLeftAlignedPopup": 1,
-                "TopPosedRightAlignedPopup": 2,
-                "LeftPosedTopAlignedPopup": 3,
-                "LeftPosedBottomAlignedPopup": 4,
-                "BottomPosedLeftAlignedPopup": 5,
-                "BottomPosedRightAlignedPopup": 6,
-                "RightPosedTopAlignedPopup": 7,
-                "RightPosedBottomAlignedPopup": 8
-            }
-        }
-        Enum {
-            name: "FlipDirection"
-            values: {
-                "NoFlip": 0,
-                "HorizontalFlip": 1,
-                "VerticalFlip": 2
-            }
-        }
-        Enum {
-            name: "IntervalAlignment"
-            values: {
-                "NoAlignment": 0,
-                "AlignToMinute": 1,
-                "AlignToHour": 2
-            }
-        }
-        Enum {
-            name: "ImmutabilityType"
-            values: {
-                "Mutable": 1,
-                "UserImmutable": 2,
-                "SystemImmutable": 4
-            }
-        }
-        Enum {
-            name: "ComponentType"
-            values: {
-                "AppletComponent": 1,
-                "DataEngineComponent": 2,
-                "ContainmentComponent": 4,
-                "WallpaperComponent": 8,
-                "GenericComponent": 16
-            }
-        }
-        Enum {
-            name: "MarginEdge"
-            values: {
-                "TopMargin": 0,
-                "BottomMargin": 1,
-                "LeftMargin": 2,
-                "RightMargin": 3
-            }
-        }
-        Enum {
-            name: "ItemStatus"
-            values: {
-                "UnknownStatus": 0,
-                "PassiveStatus": 1,
-                "ActiveStatus": 2,
-                "NeedsAttentionStatus": 3,
-                "RequiresAttentionStatus": 4,
-                "AcceptingInputStatus": 5,
-                "HiddenStatus": 6
-            }
-        }
-        Enum {
-            name: "TrustLevel"
-            values: {
-                "UnverifiableTrust": 0,
-                "CompletelyUntrusted": 1,
-                "UnknownTrusted": 2,
-                "UserTrusted": 3,
-                "SelfTrusted": 4,
-                "FullyTrusted": 5,
-                "UltimatelyTrusted": 6
-            }
-        }
-        Enum {
-            name: "BackgroundHints"
-            values: {
-                "NoBackground": 0,
-                "StandardBackground": 1,
-                "TranslucentBackground": 2,
-                "ShadowBackground": 4,
-                "ConfigurableBackground": 8,
-                "DefaultBackground": 1
-            }
-        }
-    }
-    Component {
-        name: "KSvg::WindowThumbnail"
-        defaultProperty: "data"
-        prototype: "QQuickItem"
-        exports: ["org.kde.plasma.core/WindowThumbnail 2.0"]
-        exportMetaObjectRevisions: [0]
-        Property { name: "winId"; type: "uint" }
-        Property { name: "paintedWidth"; type: "double"; isReadonly: true }
-        Property { name: "paintedHeight"; type: "double"; isReadonly: true }
-        Property { name: "thumbnailAvailable"; type: "bool"; isReadonly: true }
-        Signal { name: "paintedSizeChanged" }
-    }
-    Component {
-        name: "PlasmaQuick::Dialog"
-        defaultProperty: "mainItem"
-        prototype: "QQuickWindow"
-        exports: ["org.kde.plasma.core/Dialog 2.0"]
-        exportMetaObjectRevisions: [0]
-        Enum {
-            name: "WindowType"
-            values: {
-                "Normal": 0,
-                "Dock": 2,
-                "DialogWindow": 5,
-                "PopupMenu": 11,
-                "Tooltip": 12,
-                "Notification": 13,
-                "OnScreenDisplay": 16,
-                "CriticalNotification": 17,
-                "AppletPopup": 18
-            }
-        }
-        Enum {
-            name: "BackgroundHints"
-            values: {
-                "NoBackground": 0,
-                "StandardBackground": 1,
-                "SolidBackground": 2
-            }
-        }
-        Property { name: "mainItem"; type: "QQuickItem"; isPointer: true }
-        Property { name: "visualParent"; type: "QQuickItem"; isPointer: true }
-        Property { name: "margins"; type: "QObject"; isReadonly: true; isPointer: true }
-        Property { name: "inset"; type: "QObject"; isReadonly: true; isPointer: true }
-        Property { name: "location"; type: "KSvg::Types::Location" }
-        Property { name: "type"; type: "WindowType" }
-        Property { name: "hideOnWindowDeactivate"; type: "bool" }
-        Property { name: "outputOnly"; type: "bool" }
-        Property { name: "flags"; type: "Qt::WindowFlags" }
-        Property { name: "backgroundHints"; type: "BackgroundHints" }
-        Property { name: "visible"; type: "bool" }
-        Property { name: "appletInterface"; type: "QQuickItem"; isPointer: true }
-        Signal { name: "visibleChangedProxy" }
-        Signal { name: "windowDeactivated" }
-    }
-    Component {
-        name: "QAbstractItemModel"
-        prototype: "QObject"
-        Enum {
-            name: "LayoutChangeHint"
-            values: {
-                "NoLayoutChangeHint": 0,
-                "VerticalSortHint": 1,
-                "HorizontalSortHint": 2
-            }
-        }
-        Enum {
-            name: "CheckIndexOption"
-            values: {
-                "NoOption": 0,
-                "IndexIsValid": 1,
-                "DoNotUseParent": 2,
-                "ParentIsInvalid": 4
-            }
-        }
-        Signal {
-            name: "dataChanged"
-            Parameter { name: "topLeft"; type: "QModelIndex" }
-            Parameter { name: "bottomRight"; type: "QModelIndex" }
-            Parameter { name: "roles"; type: "QList<int>" }
-        }
-        Signal {
-            name: "dataChanged"
-            Parameter { name: "topLeft"; type: "QModelIndex" }
-            Parameter { name: "bottomRight"; type: "QModelIndex" }
-        }
-        Signal {
-            name: "headerDataChanged"
-            Parameter { name: "orientation"; type: "Qt::Orientation" }
-            Parameter { name: "first"; type: "int" }
-            Parameter { name: "last"; type: "int" }
-        }
-        Signal {
-            name: "layoutChanged"
-            Parameter { name: "parents"; type: "QList<QPersistentModelIndex>" }
-            Parameter { name: "hint"; type: "QAbstractItemModel::LayoutChangeHint" }
-        }
-        Signal {
-            name: "layoutChanged"
-            Parameter { name: "parents"; type: "QList<QPersistentModelIndex>" }
-        }
-        Signal { name: "layoutChanged" }
-        Signal {
-            name: "layoutAboutToBeChanged"
-            Parameter { name: "parents"; type: "QList<QPersistentModelIndex>" }
-            Parameter { name: "hint"; type: "QAbstractItemModel::LayoutChangeHint" }
-        }
-        Signal {
-            name: "layoutAboutToBeChanged"
-            Parameter { name: "parents"; type: "QList<QPersistentModelIndex>" }
-        }
-        Signal { name: "layoutAboutToBeChanged" }
-        Signal {
-            name: "rowsAboutToBeInserted"
-            Parameter { name: "parent"; type: "QModelIndex" }
-            Parameter { name: "first"; type: "int" }
-            Parameter { name: "last"; type: "int" }
-        }
-        Signal {
-            name: "rowsInserted"
-            Parameter { name: "parent"; type: "QModelIndex" }
-            Parameter { name: "first"; type: "int" }
-            Parameter { name: "last"; type: "int" }
-        }
-        Signal {
-            name: "rowsAboutToBeRemoved"
-            Parameter { name: "parent"; type: "QModelIndex" }
-            Parameter { name: "first"; type: "int" }
-            Parameter { name: "last"; type: "int" }
-        }
-        Signal {
-            name: "rowsRemoved"
-            Parameter { name: "parent"; type: "QModelIndex" }
-            Parameter { name: "first"; type: "int" }
-            Parameter { name: "last"; type: "int" }
-        }
-        Signal {
-            name: "columnsAboutToBeInserted"
-            Parameter { name: "parent"; type: "QModelIndex" }
-            Parameter { name: "first"; type: "int" }
-            Parameter { name: "last"; type: "int" }
-        }
-        Signal {
-            name: "columnsInserted"
-            Parameter { name: "parent"; type: "QModelIndex" }
-            Parameter { name: "first"; type: "int" }
-            Parameter { name: "last"; type: "int" }
-        }
-        Signal {
-            name: "columnsAboutToBeRemoved"
-            Parameter { name: "parent"; type: "QModelIndex" }
-            Parameter { name: "first"; type: "int" }
-            Parameter { name: "last"; type: "int" }
-        }
-        Signal {
-            name: "columnsRemoved"
-            Parameter { name: "parent"; type: "QModelIndex" }
-            Parameter { name: "first"; type: "int" }
-            Parameter { name: "last"; type: "int" }
-        }
-        Signal { name: "modelAboutToBeReset" }
-        Signal { name: "modelReset" }
-        Signal {
-            name: "rowsAboutToBeMoved"
-            Parameter { name: "sourceParent"; type: "QModelIndex" }
-            Parameter { name: "sourceStart"; type: "int" }
-            Parameter { name: "sourceEnd"; type: "int" }
-            Parameter { name: "destinationParent"; type: "QModelIndex" }
-            Parameter { name: "destinationRow"; type: "int" }
-        }
-        Signal {
-            name: "rowsMoved"
-            Parameter { name: "parent"; type: "QModelIndex" }
-            Parameter { name: "start"; type: "int" }
-            Parameter { name: "end"; type: "int" }
-            Parameter { name: "destination"; type: "QModelIndex" }
-            Parameter { name: "row"; type: "int" }
-        }
-        Signal {
-            name: "columnsAboutToBeMoved"
-            Parameter { name: "sourceParent"; type: "QModelIndex" }
-            Parameter { name: "sourceStart"; type: "int" }
-            Parameter { name: "sourceEnd"; type: "int" }
-            Parameter { name: "destinationParent"; type: "QModelIndex" }
-            Parameter { name: "destinationColumn"; type: "int" }
-        }
-        Signal {
-            name: "columnsMoved"
-            Parameter { name: "parent"; type: "QModelIndex" }
-            Parameter { name: "start"; type: "int" }
-            Parameter { name: "end"; type: "int" }
-            Parameter { name: "destination"; type: "QModelIndex" }
-            Parameter { name: "column"; type: "int" }
-        }
-        Method { name: "submit"; type: "bool" }
-        Method { name: "revert" }
-        Method {
-            name: "hasIndex"
-            type: "bool"
-            Parameter { name: "row"; type: "int" }
-            Parameter { name: "column"; type: "int" }
-            Parameter { name: "parent"; type: "QModelIndex" }
-        }
-        Method {
-            name: "hasIndex"
-            type: "bool"
-            Parameter { name: "row"; type: "int" }
-            Parameter { name: "column"; type: "int" }
-        }
-        Method {
-            name: "index"
-            type: "QModelIndex"
-            Parameter { name: "row"; type: "int" }
-            Parameter { name: "column"; type: "int" }
-            Parameter { name: "parent"; type: "QModelIndex" }
-        }
-        Method {
-            name: "index"
-            type: "QModelIndex"
-            Parameter { name: "row"; type: "int" }
-            Parameter { name: "column"; type: "int" }
-        }
-        Method {
-            name: "parent"
-            type: "QModelIndex"
-            Parameter { name: "child"; type: "QModelIndex" }
-        }
-        Method {
-            name: "sibling"
-            type: "QModelIndex"
-            Parameter { name: "row"; type: "int" }
-            Parameter { name: "column"; type: "int" }
-            Parameter { name: "idx"; type: "QModelIndex" }
-        }
-        Method {
-            name: "rowCount"
-            type: "int"
-            Parameter { name: "parent"; type: "QModelIndex" }
-        }
-        Method { name: "rowCount"; type: "int" }
-        Method {
-            name: "columnCount"
-            type: "int"
-            Parameter { name: "parent"; type: "QModelIndex" }
-        }
-        Method { name: "columnCount"; type: "int" }
-        Method {
-            name: "hasChildren"
-            type: "bool"
-            Parameter { name: "parent"; type: "QModelIndex" }
-        }
-        Method { name: "hasChildren"; type: "bool" }
-        Method {
-            name: "data"
-            type: "QVariant"
-            Parameter { name: "index"; type: "QModelIndex" }
-            Parameter { name: "role"; type: "int" }
-        }
-        Method {
-            name: "data"
-            type: "QVariant"
-            Parameter { name: "index"; type: "QModelIndex" }
-        }
-        Method {
-            name: "setData"
-            type: "bool"
-            Parameter { name: "index"; type: "QModelIndex" }
-            Parameter { name: "value"; type: "QVariant" }
-            Parameter { name: "role"; type: "int" }
-        }
-        Method {
-            name: "setData"
-            type: "bool"
-            Parameter { name: "index"; type: "QModelIndex" }
-            Parameter { name: "value"; type: "QVariant" }
-        }
-        Method {
-            name: "headerData"
-            type: "QVariant"
-            Parameter { name: "section"; type: "int" }
-            Parameter { name: "orientation"; type: "Qt::Orientation" }
-            Parameter { name: "role"; type: "int" }
-        }
-        Method {
-            name: "headerData"
-            type: "QVariant"
-            Parameter { name: "section"; type: "int" }
-            Parameter { name: "orientation"; type: "Qt::Orientation" }
-        }
-        Method {
-            name: "fetchMore"
-            Parameter { name: "parent"; type: "QModelIndex" }
-        }
-        Method {
-            name: "canFetchMore"
-            type: "bool"
-            Parameter { name: "parent"; type: "QModelIndex" }
-        }
-        Method {
-            name: "flags"
-            type: "Qt::ItemFlags"
-            Parameter { name: "index"; type: "QModelIndex" }
-        }
-        Method {
-            name: "match"
-            type: "QModelIndexList"
-            Parameter { name: "start"; type: "QModelIndex" }
-            Parameter { name: "role"; type: "int" }
-            Parameter { name: "value"; type: "QVariant" }
-            Parameter { name: "hits"; type: "int" }
-            Parameter { name: "flags"; type: "Qt::MatchFlags" }
-        }
-        Method {
-            name: "match"
-            type: "QModelIndexList"
-            Parameter { name: "start"; type: "QModelIndex" }
-            Parameter { name: "role"; type: "int" }
-            Parameter { name: "value"; type: "QVariant" }
-            Parameter { name: "hits"; type: "int" }
-        }
-        Method {
-            name: "match"
-            type: "QModelIndexList"
-            Parameter { name: "start"; type: "QModelIndex" }
-            Parameter { name: "role"; type: "int" }
-            Parameter { name: "value"; type: "QVariant" }
-        }
-    }
-    Component {
-        name: "QAbstractProxyModel"
-        prototype: "QAbstractItemModel"
-        Property { name: "sourceModel"; type: "QAbstractItemModel"; isPointer: true }
-        Method {
-            name: "mapToSource"
-            type: "QModelIndex"
-            Parameter { name: "proxyIndex"; type: "QModelIndex" }
-        }
-        Method {
-            name: "mapFromSource"
-            type: "QModelIndex"
-            Parameter { name: "sourceIndex"; type: "QModelIndex" }
-        }
-        Method {
-            name: "mapSelectionToSource"
-            type: "QItemSelection"
-            Parameter { name: "selection"; type: "QItemSelection" }
-        }
-        Method {
-            name: "mapSelectionFromSource"
-            type: "QItemSelection"
-            Parameter { name: "selection"; type: "QItemSelection" }
-        }
-    }
-    Component {
-        name: "QQmlPropertyMap"
-        prototype: "QObject"
-        Signal {
-            name: "valueChanged"
-            Parameter { name: "key"; type: "string" }
-            Parameter { name: "value"; type: "QVariant" }
-        }
-        Method { name: "keys"; type: "QStringList" }
-    }
-    Component {
-        name: "QQuickItem"
-        defaultProperty: "data"
-        prototype: "QObject"
-        Enum {
-            name: "Flags"
-            values: {
-                "ItemClipsChildrenToShape": 1,
-                "ItemAcceptsInputMethod": 2,
-                "ItemIsFocusScope": 4,
-                "ItemHasContents": 8,
-                "ItemAcceptsDrops": 16
-            }
-        }
-        Enum {
-            name: "TransformOrigin"
-            values: {
-                "TopLeft": 0,
-                "Top": 1,
-                "TopRight": 2,
-                "Left": 3,
-                "Center": 4,
-                "Right": 5,
-                "BottomLeft": 6,
-                "Bottom": 7,
-                "BottomRight": 8
-            }
-        }
-        Property { name: "parent"; type: "QQuickItem"; isPointer: true }
-        Property { name: "data"; type: "QObject"; isList: true; isReadonly: true }
-        Property { name: "resources"; type: "QObject"; isList: true; isReadonly: true }
-        Property { name: "children"; type: "QQuickItem"; isList: true; isReadonly: true }
-        Property { name: "x"; type: "double" }
-        Property { name: "y"; type: "double" }
-        Property { name: "z"; type: "double" }
-        Property { name: "width"; type: "double" }
-        Property { name: "height"; type: "double" }
-        Property { name: "opacity"; type: "double" }
-        Property { name: "enabled"; type: "bool" }
-        Property { name: "visible"; type: "bool" }
-        Property { name: "visibleChildren"; type: "QQuickItem"; isList: true; isReadonly: true }
-        Property { name: "states"; type: "QQuickState"; isList: true; isReadonly: true }
-        Property { name: "transitions"; type: "QQuickTransition"; isList: true; isReadonly: true }
-        Property { name: "state"; type: "string" }
-        Property { name: "childrenRect"; type: "QRectF"; isReadonly: true }
-        Property { name: "anchors"; type: "QQuickAnchors"; isReadonly: true; isPointer: true }
-        Property { name: "left"; type: "QQuickAnchorLine"; isReadonly: true }
-        Property { name: "right"; type: "QQuickAnchorLine"; isReadonly: true }
-        Property { name: "horizontalCenter"; type: "QQuickAnchorLine"; isReadonly: true }
-        Property { name: "top"; type: "QQuickAnchorLine"; isReadonly: true }
-        Property { name: "bottom"; type: "QQuickAnchorLine"; isReadonly: true }
-        Property { name: "verticalCenter"; type: "QQuickAnchorLine"; isReadonly: true }
-        Property { name: "baseline"; type: "QQuickAnchorLine"; isReadonly: true }
-        Property { name: "baselineOffset"; type: "double" }
-        Property { name: "clip"; type: "bool" }
-        Property { name: "focus"; type: "bool" }
-        Property { name: "activeFocus"; type: "bool"; isReadonly: true }
-        Property { name: "activeFocusOnTab"; revision: 1; type: "bool" }
-        Property { name: "rotation"; type: "double" }
-        Property { name: "scale"; type: "double" }
-        Property { name: "transformOrigin"; type: "TransformOrigin" }
-        Property { name: "transformOriginPoint"; type: "QPointF"; isReadonly: true }
-        Property { name: "transform"; type: "QQuickTransform"; isList: true; isReadonly: true }
-        Property { name: "smooth"; type: "bool" }
-        Property { name: "antialiasing"; type: "bool" }
-        Property { name: "implicitWidth"; type: "double" }
-        Property { name: "implicitHeight"; type: "double" }
-        Property { name: "containmentMask"; revision: 11; type: "QObject"; isPointer: true }
-        Property { name: "layer"; type: "QQuickItemLayer"; isReadonly: true; isPointer: true }
-        Signal {
-            name: "childrenRectChanged"
-            Parameter { type: "QRectF" }
-        }
-        Signal {
-            name: "baselineOffsetChanged"
-            Parameter { type: "double" }
-        }
-        Signal {
-            name: "stateChanged"
-            Parameter { type: "string" }
-        }
-        Signal {
-            name: "focusChanged"
-            Parameter { type: "bool" }
-        }
-        Signal {
-            name: "activeFocusChanged"
-            Parameter { type: "bool" }
-        }
-        Signal {
-            name: "activeFocusOnTabChanged"
-            revision: 1
-            Parameter { type: "bool" }
-        }
-        Signal {
-            name: "parentChanged"
-            Parameter { type: "QQuickItem"; isPointer: true }
-        }
-        Signal {
-            name: "transformOriginChanged"
-            Parameter { type: "TransformOrigin" }
-        }
-        Signal {
-            name: "smoothChanged"
-            Parameter { type: "bool" }
-        }
-        Signal {
-            name: "antialiasingChanged"
-            Parameter { type: "bool" }
-        }
-        Signal {
-            name: "clipChanged"
-            Parameter { type: "bool" }
-        }
-        Signal {
-            name: "windowChanged"
-            revision: 1
-            Parameter { name: "window"; type: "QQuickWindow"; isPointer: true }
-        }
-        Signal { name: "containmentMaskChanged"; revision: 11 }
-        Method { name: "update" }
-        Method {
-            name: "grabToImage"
-            revision: 4
-            type: "bool"
-            Parameter { name: "callback"; type: "QJSValue" }
-            Parameter { name: "targetSize"; type: "QSize" }
-        }
-        Method {
-            name: "grabToImage"
-            revision: 4
-            type: "bool"
-            Parameter { name: "callback"; type: "QJSValue" }
-        }
-        Method {
-            name: "contains"
-            type: "bool"
-            Parameter { name: "point"; type: "QPointF" }
-        }
-        Method {
-            name: "mapFromItem"
-            Parameter { type: "QQmlV4Function"; isPointer: true }
-        }
-        Method {
-            name: "mapToItem"
-            Parameter { type: "QQmlV4Function"; isPointer: true }
-        }
-        Method {
-            name: "mapFromGlobal"
-            revision: 7
-            Parameter { type: "QQmlV4Function"; isPointer: true }
-        }
-        Method {
-            name: "mapToGlobal"
-            revision: 7
-            Parameter { type: "QQmlV4Function"; isPointer: true }
-        }
-        Method { name: "forceActiveFocus" }
-        Method {
-            name: "forceActiveFocus"
-            Parameter { name: "reason"; type: "Qt::FocusReason" }
-        }
-        Method {
-            name: "nextItemInFocusChain"
-            revision: 1
-            type: "QQuickItem*"
-            Parameter { name: "forward"; type: "bool" }
-        }
-        Method { name: "nextItemInFocusChain"; revision: 1; type: "QQuickItem*" }
-        Method {
-            name: "childAt"
-            type: "QQuickItem*"
-            Parameter { name: "x"; type: "double" }
-            Parameter { name: "y"; type: "double" }
-        }
-    }
-    Component {
-        name: "QSortFilterProxyModel"
-        prototype: "QAbstractProxyModel"
-        Property { name: "filterRegExp"; type: "QRegExp" }
-        Property { name: "filterRegularExpression"; type: "QRegularExpression" }
-        Property { name: "filterKeyColumn"; type: "int" }
-        Property { name: "dynamicSortFilter"; type: "bool" }
-        Property { name: "filterCaseSensitivity"; type: "Qt::CaseSensitivity" }
-        Property { name: "sortCaseSensitivity"; type: "Qt::CaseSensitivity" }
-        Property { name: "isSortLocaleAware"; type: "bool" }
-        Property { name: "sortRole"; type: "int" }
-        Property { name: "filterRole"; type: "int" }
-        Property { name: "recursiveFilteringEnabled"; type: "bool" }
-        Signal {
-            name: "dynamicSortFilterChanged"
-            Parameter { name: "dynamicSortFilter"; type: "bool" }
-        }
-        Signal {
-            name: "filterCaseSensitivityChanged"
-            Parameter { name: "filterCaseSensitivity"; type: "Qt::CaseSensitivity" }
-        }
-        Signal {
-            name: "sortCaseSensitivityChanged"
-            Parameter { name: "sortCaseSensitivity"; type: "Qt::CaseSensitivity" }
-        }
-        Signal {
-            name: "sortLocaleAwareChanged"
-            Parameter { name: "sortLocaleAware"; type: "bool" }
-        }
-        Signal {
-            name: "sortRoleChanged"
-            Parameter { name: "sortRole"; type: "int" }
-        }
-        Signal {
-            name: "filterRoleChanged"
-            Parameter { name: "filterRole"; type: "int" }
-        }
-        Signal {
-            name: "recursiveFilteringEnabledChanged"
-            Parameter { name: "recursiveFilteringEnabled"; type: "bool" }
-        }
-        Method {
-            name: "setFilterRegExp"
-            Parameter { name: "pattern"; type: "string" }
-        }
-        Method {
-            name: "setFilterRegExp"
-            Parameter { name: "regExp"; type: "QRegExp" }
-        }
-        Method {
-            name: "setFilterRegularExpression"
-            Parameter { name: "pattern"; type: "string" }
-        }
-        Method {
-            name: "setFilterRegularExpression"
-            Parameter { name: "regularExpression"; type: "QRegularExpression" }
-        }
-        Method {
-            name: "setFilterWildcard"
-            Parameter { name: "pattern"; type: "string" }
-        }
-        Method {
-            name: "setFilterFixedString"
-            Parameter { name: "pattern"; type: "string" }
-        }
-        Method { name: "clear" }
-        Method { name: "invalidate" }
-    }
-    Component {
-        name: "QWindow"
-        prototype: "QObject"
-        Enum {
-            name: "Visibility"
-            values: {
-                "Hidden": 0,
-                "AutomaticVisibility": 1,
-                "Windowed": 2,
-                "Minimized": 3,
-                "Maximized": 4,
-                "FullScreen": 5
-            }
-        }
-        Enum {
-            name: "AncestorMode"
-            values: {
-                "ExcludeTransients": 0,
-                "IncludeTransients": 1
-            }
-        }
-        Property { name: "title"; type: "string" }
-        Property { name: "modality"; type: "Qt::WindowModality" }
-        Property { name: "flags"; type: "Qt::WindowFlags" }
-        Property { name: "x"; type: "int" }
-        Property { name: "y"; type: "int" }
-        Property { name: "width"; type: "int" }
-        Property { name: "height"; type: "int" }
-        Property { name: "minimumWidth"; type: "int" }
-        Property { name: "minimumHeight"; type: "int" }
-        Property { name: "maximumWidth"; type: "int" }
-        Property { name: "maximumHeight"; type: "int" }
-        Property { name: "visible"; type: "bool" }
-        Property { name: "active"; revision: 1; type: "bool"; isReadonly: true }
-        Property { name: "visibility"; revision: 1; type: "Visibility" }
-        Property { name: "contentOrientation"; type: "Qt::ScreenOrientation" }
-        Property { name: "opacity"; revision: 1; type: "double" }
-        Property { name: "transientParent"; revision: 13; type: "QWindow"; isPointer: true }
-        Signal {
-            name: "screenChanged"
-            Parameter { name: "screen"; type: "QScreen"; isPointer: true }
-        }
-        Signal {
-            name: "modalityChanged"
-            Parameter { name: "modality"; type: "Qt::WindowModality" }
-        }
-        Signal {
-            name: "windowStateChanged"
-            Parameter { name: "windowState"; type: "Qt::WindowState" }
-        }
-        Signal {
-            name: "windowTitleChanged"
-            revision: 2
-            Parameter { name: "title"; type: "string" }
-        }
-        Signal {
-            name: "xChanged"
-            Parameter { name: "arg"; type: "int" }
-        }
-        Signal {
-            name: "yChanged"
-            Parameter { name: "arg"; type: "int" }
-        }
-        Signal {
-            name: "widthChanged"
-            Parameter { name: "arg"; type: "int" }
-        }
-        Signal {
-            name: "heightChanged"
-            Parameter { name: "arg"; type: "int" }
-        }
-        Signal {
-            name: "minimumWidthChanged"
-            Parameter { name: "arg"; type: "int" }
-        }
-        Signal {
-            name: "minimumHeightChanged"
-            Parameter { name: "arg"; type: "int" }
-        }
-        Signal {
-            name: "maximumWidthChanged"
-            Parameter { name: "arg"; type: "int" }
-        }
-        Signal {
-            name: "maximumHeightChanged"
-            Parameter { name: "arg"; type: "int" }
-        }
-        Signal {
-            name: "visibleChanged"
-            Parameter { name: "arg"; type: "bool" }
-        }
-        Signal {
-            name: "visibilityChanged"
-            revision: 1
-            Parameter { name: "visibility"; type: "QWindow::Visibility" }
-        }
-        Signal { name: "activeChanged"; revision: 1 }
-        Signal {
-            name: "contentOrientationChanged"
-            Parameter { name: "orientation"; type: "Qt::ScreenOrientation" }
-        }
-        Signal {
-            name: "focusObjectChanged"
-            Parameter { name: "object"; type: "QObject"; isPointer: true }
-        }
-        Signal {
-            name: "opacityChanged"
-            revision: 1
-            Parameter { name: "opacity"; type: "double" }
-        }
-        Signal {
-            name: "transientParentChanged"
-            revision: 13
-            Parameter { name: "transientParent"; type: "QWindow"; isPointer: true }
-        }
-        Method { name: "requestActivate"; revision: 1 }
-        Method {
-            name: "setVisible"
-            Parameter { name: "visible"; type: "bool" }
-        }
-        Method { name: "show" }
-        Method { name: "hide" }
-        Method { name: "showMinimized" }
-        Method { name: "showMaximized" }
-        Method { name: "showFullScreen" }
-        Method { name: "showNormal" }
-        Method { name: "close"; type: "bool" }
-        Method { name: "raise" }
-        Method { name: "lower" }
-        Method {
-            name: "startSystemResize"
-            type: "bool"
-            Parameter { name: "edges"; type: "Qt::Edges" }
-        }
-        Method { name: "startSystemMove"; type: "bool" }
-        Method {
-            name: "setTitle"
-            Parameter { type: "string" }
-        }
-        Method {
-            name: "setX"
-            Parameter { name: "arg"; type: "int" }
-        }
-        Method {
-            name: "setY"
-            Parameter { name: "arg"; type: "int" }
-        }
-        Method {
-            name: "setWidth"
-            Parameter { name: "arg"; type: "int" }
-        }
-        Method {
-            name: "setHeight"
-            Parameter { name: "arg"; type: "int" }
-        }
-        Method {
-            name: "setGeometry"
-            Parameter { name: "posx"; type: "int" }
-            Parameter { name: "posy"; type: "int" }
-            Parameter { name: "w"; type: "int" }
-            Parameter { name: "h"; type: "int" }
-        }
-        Method {
-            name: "setGeometry"
-            Parameter { name: "rect"; type: "QRect" }
-        }
-        Method {
-            name: "setMinimumWidth"
-            Parameter { name: "w"; type: "int" }
-        }
-        Method {
-            name: "setMinimumHeight"
-            Parameter { name: "h"; type: "int" }
-        }
-        Method {
-            name: "setMaximumWidth"
-            Parameter { name: "w"; type: "int" }
-        }
-        Method {
-            name: "setMaximumHeight"
-            Parameter { name: "h"; type: "int" }
-        }
-        Method {
-            name: "alert"
-            revision: 1
-            Parameter { name: "msec"; type: "int" }
-        }
-        Method { name: "requestUpdate"; revision: 3 }
-    }
-    Component {
-        name: "ServiceOperationStatus"
-        prototype: "QObject"
-        exports: ["org.kde.plasma.core/ServiceOperationStatus 2.0"]
-        exportMetaObjectRevisions: [0]
-        Property { name: "service"; type: "KSvg::Service"; isPointer: true }
-        Property { name: "operation"; type: "string" }
-        Property { name: "enabled"; type: "bool" }
-    }
-    Component {
-        name: "ToolTip"
-        defaultProperty: "data"
-        prototype: "QQuickItem"
-        exports: ["org.kde.plasma.core/ToolTipArea 2.0"]
-        exportMetaObjectRevisions: [0]
-        Property { name: "mainItem"; type: "QQuickItem"; isPointer: true }
-        Property { name: "mainText"; type: "string" }
-        Property { name: "subText"; type: "string" }
-        Property { name: "textFormat"; type: "int" }
-        Property { name: "icon"; type: "QVariant" }
-        Property { name: "containsMouse"; type: "bool"; isReadonly: true }
-        Property { name: "location"; type: "KSvg::Types::Location" }
-        Property { name: "image"; type: "QVariant" }
-        Property { name: "active"; type: "bool" }
-        Property { name: "interactive"; type: "bool" }
-        Property { name: "timeout"; type: "int" }
-        Signal { name: "aboutToShow" }
-        Signal {
-            name: "toolTipVisibleChanged"
-            Parameter { name: "toolTipVisible"; type: "bool" }
-        }
-        Method { name: "showToolTip" }
-        Method { name: "hideToolTip" }
-        Method { name: "hideImmediately" }
-    }
-    Component {
-        name: "Units"
-        prototype: "QObject"
-        exports: ["org.kde.plasma.core/Units 2.0"]
-        isCreatable: false
-        isSingleton: true
-        exportMetaObjectRevisions: [0]
-        Property { name: "gridUnit"; type: "int"; isReadonly: true }
-        Property { name: "iconSizes"; type: "QQmlPropertyMap"; isReadonly: true; isPointer: true }
-        Property { name: "iconSizeHints"; type: "QQmlPropertyMap"; isReadonly: true; isPointer: true }
-        Property { name: "smallSpacing"; type: "int"; isReadonly: true }
-        Property { name: "mediumSpacing"; type: "int"; isReadonly: true }
-        Property { name: "largeSpacing"; type: "int"; isReadonly: true }
-        Property { name: "devicePixelRatio"; type: "double"; isReadonly: true }
-        Property { name: "longDuration"; type: "int"; isReadonly: true }
-        Property { name: "shortDuration"; type: "int"; isReadonly: true }
-        Property { name: "veryShortDuration"; type: "int"; isReadonly: true }
-        Property { name: "veryLongDuration"; type: "int"; isReadonly: true }
-        Property { name: "humanMoment"; type: "int"; isReadonly: true }
-        Signal { name: "spacingChanged" }
-        Signal { name: "durationChanged" }
-        Method {
-            name: "roundToIconSize"
-            type: "int"
-            Parameter { name: "size"; type: "int" }
-        }
-    }
-    Component {
-        prototype: "SizeGroup"
-        name: "org.kde.plasma.core/AppHeaderSizeGroup 2.2"
-        exports: ["org.kde.plasma.core/AppHeaderSizeGroup 2.2"]
-        exportMetaObjectRevisions: [2]
-        isComposite: true
-        isCreatable: false
-        isSingleton: true
-    }
-}
diff -pruN 6.0.0-1/src/declarativeimports/svgitem.cpp 6.3.0-1/src/declarativeimports/svgitem.cpp
--- 6.0.0-1/src/declarativeimports/svgitem.cpp	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/declarativeimports/svgitem.cpp	2024-05-31 13:28:20.000000000 +0000
@@ -16,8 +16,6 @@
 
 #include "managedtexturenode.h"
 
-#include <cmath> //floor()
-
 #include <Kirigami/Platform/PlatformTheme>
 #include <debug_p.h>
 
@@ -267,10 +265,7 @@ void SvgItem::geometryChange(const QRect
 
 void SvgItem::updateDevicePixelRatio()
 {
-    // devicepixelratio is always set integer in the svg, so needs at least 192dpi to double up.
-    //(it needs to be integer to have lines contained inside a svg piece to keep being pixel aligned)
-    const auto newDevicePixelRatio = std::max<qreal>(1.0, floor(window() ? window()->devicePixelRatio() : qApp->devicePixelRatio()));
-
+    const auto newDevicePixelRatio = std::max<qreal>(1.0, (window() ? window()->devicePixelRatio() : qApp->devicePixelRatio()));
     if (newDevicePixelRatio != m_svg->devicePixelRatio()) {
         m_svg->setDevicePixelRatio(newDevicePixelRatio);
         m_textureChanged = true;
diff -pruN 6.0.0-1/src/declarativeimports/svgitem.h 6.3.0-1/src/declarativeimports/svgitem.h
--- 6.0.0-1/src/declarativeimports/svgitem.h	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/declarativeimports/svgitem.h	2024-05-31 13:28:20.000000000 +0000
@@ -10,6 +10,8 @@
 #include <QImage>
 #include <QQuickItem>
 
+#include <qqmlregistration.h>
+
 namespace Kirigami
 {
 namespace Platform
@@ -29,6 +31,7 @@ class Svg;
 class SvgItem : public QQuickItem
 {
     Q_OBJECT
+    QML_ELEMENT
 
     /**
      * @brief This property specifies the relative path of the Svg in the theme.
diff -pruN 6.0.0-1/src/declarativeimports/types.h 6.3.0-1/src/declarativeimports/types.h
--- 6.0.0-1/src/declarativeimports/types.h	1970-01-01 00:00:00.000000000 +0000
+++ 6.3.0-1/src/declarativeimports/types.h	2024-05-31 13:28:20.000000000 +0000
@@ -0,0 +1,45 @@
+/*
+    SPDX-FileCopyrightText: 2023 Nicolas Fella <nicolas.fella@gmx.de>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
+
+#ifndef KSVG_TYPES_H
+#define KSVG_TYPES_H
+
+#include <QQmlEngine>
+
+#include <Kirigami/Platform/PlatformTheme>
+
+#include <framesvg.h>
+#include <svg.h>
+
+struct PlatformThemeForeign {
+    Q_GADGET
+    QML_ANONYMOUS
+    QML_FOREIGN(Kirigami::Platform::PlatformTheme)
+};
+
+struct SvgForeign {
+    Q_GADGET
+    QML_ELEMENT
+    QML_NAMED_ELEMENT(Svg)
+    QML_FOREIGN(KSvg::Svg)
+};
+
+struct FrameSvgForeign {
+    Q_GADGET
+    QML_ELEMENT
+    QML_NAMED_ELEMENT(FrameSvg)
+    QML_FOREIGN(KSvg::FrameSvg)
+};
+
+struct ImageSetForeign {
+    Q_GADGET
+    QML_ELEMENT
+    QML_SINGLETON
+    QML_NAMED_ELEMENT(ImageSet)
+    QML_FOREIGN(KSvg::ImageSet)
+};
+
+#endif
diff -pruN 6.0.0-1/src/ksvg/CMakeLists.txt 6.3.0-1/src/ksvg/CMakeLists.txt
--- 6.0.0-1/src/ksvg/CMakeLists.txt	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/ksvg/CMakeLists.txt	2024-05-31 13:28:20.000000000 +0000
@@ -8,6 +8,8 @@ set(KSVG_INSTALL_INCLUDEDIR "${KDE_INSTA
 add_library(KF6Svg)
 add_library(KF6::Svg ALIAS KF6Svg)
 
+qt_extract_metatypes(KF6Svg)
+
 set_target_properties(KF6Svg PROPERTIES
     VERSION     ${KSVG_VERSION}
     SOVERSION   ${KSVG_SOVERSION}
@@ -46,7 +48,6 @@ PUBLIC
     KF6::ConfigCore
 PRIVATE
     Qt6::Svg
-    Qt6::Quick
     KF6::Archive
     KF6::CoreAddons
     KF6::GuiAddons #kimagecache
diff -pruN 6.0.0-1/src/ksvg/framesvg.cpp 6.3.0-1/src/ksvg/framesvg.cpp
--- 6.0.0-1/src/ksvg/framesvg.cpp	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/ksvg/framesvg.cpp	2024-05-31 13:28:20.000000000 +0000
@@ -15,7 +15,7 @@
 #include <QCryptographicHash>
 #include <QPainter>
 #include <QRegion>
-#include <QSize>
+#include <QSizeF>
 #include <QStringBuilder>
 #include <QTimer>
 
@@ -188,7 +188,7 @@ void FrameSvg::resizeFrame(const QSizeF
 QSizeF FrameSvg::frameSize() const
 {
     if (!d->frame) {
-        return QSize(-1, -1);
+        return QSizeF(-1, -1);
     } else {
         return d->frameSize(d->frame.data());
     }
@@ -478,9 +478,6 @@ QPixmap FrameSvgPrivate::alphaMask()
 
     if (maskFrame->cachedBackground.isNull()) {
         generateBackground(maskFrame);
-        // When we take the maskFrame from cache, the pixel ratio gets
-        // reset to 1
-        maskFrame->cachedBackground.setDevicePixelRatio(q->devicePixelRatio());
     }
 
     return maskFrame->cachedBackground;
@@ -539,8 +536,8 @@ void FrameSvgPrivate::generateBackground
     }
 
     // Overlays
-    QSize overlaySize;
-    QPoint actualOverlayPos = QPoint(0, 0);
+    QSizeF overlaySize;
+    QPointF actualOverlayPos = QPointF(0, 0);
     if (overlayAvailable && !overlayCached) {
         overlaySize = q->elementSize(frame->prefix % QLatin1String("overlay")).toSize();
 
@@ -566,13 +563,13 @@ void FrameSvgPrivate::generateBackground
         // Tiling?
         if (q->hasElement(frame->prefix % QLatin1String("hint-overlay-tile-horizontal"))
             || q->hasElement(frame->prefix % QLatin1String("hint-overlay-tile-vertical"))) {
-            QSize s = q->size().toSize();
+            QSizeF s = q->size().toSize();
             q->resize(q->elementSize(frame->prefix % QLatin1String("overlay")));
 
-            overlayPainter.drawTiledPixmap(QRect(QPoint(0, 0), overlaySize), q->pixmap(frame->prefix % QLatin1String("overlay")));
+            overlayPainter.drawTiledPixmap(QRectF(QPointF(0, 0), overlaySize), q->pixmap(frame->prefix % QLatin1String("overlay")));
             q->resize(s);
         } else {
-            q->paint(&overlayPainter, QRect(actualOverlayPos, overlaySize), frame->prefix % QLatin1String("overlay"));
+            q->paint(&overlayPainter, QRectF(actualOverlayPos, overlaySize), frame->prefix % QLatin1String("overlay"));
         }
 
         overlayPainter.end();
@@ -585,14 +582,14 @@ void FrameSvgPrivate::generateBackground
     if (!overlay.isNull()) {
         QPainter p(&frame->cachedBackground);
         p.setCompositionMode(QPainter::CompositionMode_SourceOver);
-        p.drawPixmap(actualOverlayPos, overlay, QRect(actualOverlayPos, overlaySize));
+        p.drawPixmap(actualOverlayPos, overlay, QRectF(actualOverlayPos, overlaySize));
     }
 }
 
 void FrameSvgPrivate::generateFrameBackground(const QSharedPointer<FrameData> &frame)
 {
     // qCDebug(LOG_KSVG) << "generating background";
-    const QSize size = frameSize(frame).toSize() * q->devicePixelRatio();
+    const QSizeF size = frameSize(frame) * q->devicePixelRatio();
 
     if (!size.isValid()) {
 #ifndef NDEBUG
@@ -605,13 +602,14 @@ void FrameSvgPrivate::generateFrameBackg
         return;
     }
 
-    frame->cachedBackground = QPixmap(size);
+    // Don't cut away pieces of the frame
+    frame->cachedBackground = QPixmap(QSize(std::ceil(size.width()), std::ceil(size.height())));
     frame->cachedBackground.fill(Qt::transparent);
     QPainter p(&frame->cachedBackground);
     p.setCompositionMode(QPainter::CompositionMode_Source);
     p.setRenderHint(QPainter::SmoothPixmapTransform);
 
-    QRect contentRect = contentGeometry(frame, size);
+    QRectF contentRect = contentGeometry(frame, size);
     paintCenter(p, frame, contentRect, size);
 
     paintCorner(p, frame, FrameSvg::LeftBorder | FrameSvg::TopBorder, contentRect);
@@ -620,25 +618,26 @@ void FrameSvgPrivate::generateFrameBackg
     paintCorner(p, frame, FrameSvg::RightBorder | FrameSvg::BottomBorder, contentRect);
 
     // Sides
-    const int leftHeight = q->elementSize(frame->prefix % QLatin1String("left")).height();
-    paintBorder(p, frame, FrameSvg::LeftBorder, QSize(frame->leftWidth, leftHeight) * q->devicePixelRatio(), contentRect);
-    const int rightHeight = q->elementSize(frame->prefix % QLatin1String("right")).height();
-    paintBorder(p, frame, FrameSvg::RightBorder, QSize(frame->rightWidth, rightHeight) * q->devicePixelRatio(), contentRect);
-
-    const int topWidth = q->elementSize(frame->prefix % QLatin1String("top")).width();
-    paintBorder(p, frame, FrameSvg::TopBorder, QSize(topWidth, frame->topHeight) * q->devicePixelRatio(), contentRect);
-    const int bottomWidth = q->elementSize(frame->prefix % QLatin1String("bottom")).width();
-    paintBorder(p, frame, FrameSvg::BottomBorder, QSize(bottomWidth, frame->bottomHeight) * q->devicePixelRatio(), contentRect);
+    const qreal leftHeight = q->elementSize(frame->prefix % QLatin1String("left")).height();
+    paintBorder(p, frame, FrameSvg::LeftBorder, QSizeF(frame->leftWidth, leftHeight) * q->devicePixelRatio(), contentRect);
+    const qreal rightHeight = q->elementSize(frame->prefix % QLatin1String("right")).height();
+    paintBorder(p, frame, FrameSvg::RightBorder, QSizeF(frame->rightWidth, rightHeight) * q->devicePixelRatio(), contentRect);
+
+    const qreal topWidth = q->elementSize(frame->prefix % QLatin1String("top")).width();
+    paintBorder(p, frame, FrameSvg::TopBorder, QSizeF(topWidth, frame->topHeight) * q->devicePixelRatio(), contentRect);
+    const qreal bottomWidth = q->elementSize(frame->prefix % QLatin1String("bottom")).width();
+    paintBorder(p, frame, FrameSvg::BottomBorder, QSizeF(bottomWidth, frame->bottomHeight) * q->devicePixelRatio(), contentRect);
     p.end();
 
+    // Set the devicePixelRatio only at the end, drawing all happened in device pixels
     frame->cachedBackground.setDevicePixelRatio(q->devicePixelRatio());
 }
 
-QRect FrameSvgPrivate::contentGeometry(const QSharedPointer<FrameData> &frame, const QSize &size) const
+QRectF FrameSvgPrivate::contentGeometry(const QSharedPointer<FrameData> &frame, const QSizeF &size) const
 {
-    const QSize contentSize(size.width() - frame->leftWidth * q->devicePixelRatio() - frame->rightWidth * q->devicePixelRatio(),
-                            size.height() - frame->topHeight * q->devicePixelRatio() - frame->bottomHeight * q->devicePixelRatio());
-    QRect contentRect(QPoint(0, 0), contentSize);
+    const QSizeF contentSize(size.width() - frame->leftWidth * q->devicePixelRatio() - frame->rightWidth * q->devicePixelRatio(),
+                             size.height() - frame->topHeight * q->devicePixelRatio() - frame->bottomHeight * q->devicePixelRatio());
+    QRectF contentRect(QPointF(0, 0), contentSize);
     if (frame->enabledBorders & FrameSvg::LeftBorder && q->hasElement(frame->prefix % QLatin1String("left"))) {
         contentRect.translate(frame->leftWidth * q->devicePixelRatio(), 0);
     }
@@ -660,7 +659,7 @@ void FrameSvgPrivate::updateFrameData(ui
 
         const QString oldPath = fd->imagePath;
         const FrameSvg::EnabledBorders oldBorders = fd->enabledBorders;
-        const QSize currentSize = fd->frameSize;
+        const QSizeF currentSize = fd->frameSize;
 
         fd->enabledBorders = enabledBorders;
         fd->frameSize = pendingFrameSize;
@@ -717,27 +716,28 @@ void FrameSvgPrivate::updateFrameData(ui
     }
 }
 
-void FrameSvgPrivate::paintCenter(QPainter &p, const QSharedPointer<FrameData> &frame, const QRect &contentRect, const QSize &fullSize)
+void FrameSvgPrivate::paintCenter(QPainter &p, const QSharedPointer<FrameData> &frame, const QRectF &contentRect, const QSizeF &fullSize)
 {
+    // fullSize and contentRect are in device pixels
     if (!contentRect.isEmpty()) {
         const QString centerElementId = frame->prefix % QLatin1String("center");
         if (frame->tileCenter) {
-            QSize centerTileSize = q->elementSize(centerElementId).toSize();
-            QPixmap center(centerTileSize);
+            QSizeF centerTileSize = q->elementSize(centerElementId);
+            QPixmap center(centerTileSize.toSize());
             center.fill(Qt::transparent);
 
             QPainter centerPainter(&center);
             centerPainter.setCompositionMode(QPainter::CompositionMode_Source);
-            q->paint(&centerPainter, QRect(QPoint(0, 0), centerTileSize), centerElementId);
+            q->paint(&centerPainter, QRectF(QPointF(0, 0), centerTileSize), centerElementId);
 
             if (frame->composeOverBorder) {
-                p.drawTiledPixmap(QRect(QPoint(0, 0), fullSize), center);
+                p.drawTiledPixmap(QRectF(QPointF(0, 0), fullSize), center);
             } else {
                 p.drawTiledPixmap(FrameSvgHelpers::sectionRect(FrameSvg::NoBorder, contentRect, fullSize * q->devicePixelRatio()), center);
             }
         } else {
             if (frame->composeOverBorder) {
-                q->paint(&p, QRect(QPoint(0, 0), fullSize), centerElementId);
+                q->paint(&p, QRectF(QPointF(0, 0), fullSize), centerElementId);
             } else {
                 q->paint(&p, FrameSvgHelpers::sectionRect(FrameSvg::NoBorder, contentRect, fullSize * q->devicePixelRatio()), centerElementId);
             }
@@ -746,7 +746,7 @@ void FrameSvgPrivate::paintCenter(QPaint
 
     if (frame->composeOverBorder) {
         p.setCompositionMode(QPainter::CompositionMode_DestinationIn);
-        p.drawPixmap(QRect(QPoint(0, 0), fullSize), alphaMask());
+        p.drawPixmap(QRectF(QPointF(0, 0), fullSize), alphaMask(), QRectF(QPointF(0, 0), alphaMask().size()));
         p.setCompositionMode(QPainter::CompositionMode_SourceOver);
     }
 }
@@ -754,35 +754,51 @@ void FrameSvgPrivate::paintCenter(QPaint
 void FrameSvgPrivate::paintBorder(QPainter &p,
                                   const QSharedPointer<FrameData> &frame,
                                   const FrameSvg::EnabledBorders borders,
-                                  const QSize &size,
-                                  const QRect &contentRect) const
+                                  const QSizeF &size,
+                                  const QRectF &contentRect) const
 {
+    // size and contentRect are in device pixels
     QString side = frame->prefix % FrameSvgHelpers::borderToElementId(borders);
     if (frame->enabledBorders & borders && q->hasElement(side) && !size.isEmpty()) {
         if (frame->stretchBorders) {
             q->paint(&p, FrameSvgHelpers::sectionRect(borders, contentRect, frame->frameSize * q->devicePixelRatio()), side);
         } else {
-            QPixmap px(size);
+            QSize grownSize(std::ceil(size.width()), std::ceil(size.height()));
+            QPixmap px(grownSize);
+            // QPixmap px(QSize(std::ceil(size.width()), std::ceil(size.height())));
             px.fill(Qt::transparent);
 
             QPainter sidePainter(&px);
             sidePainter.setCompositionMode(QPainter::CompositionMode_Source);
-            q->paint(&sidePainter, QRect(QPoint(0, 0), size), side);
+            // A QRect as we have to exactly fill a QPixmap of integer size, prefer going slightly outside it to not have empty edges in the pixmap to tile
+            q->paint(&sidePainter, QRect(QPoint(0, 0), grownSize), side);
 
-            p.drawTiledPixmap(FrameSvgHelpers::sectionRect(borders, contentRect, frame->frameSize * q->devicePixelRatio()), px);
+            // We are composing QPixmaps here, so all objects with integer size
+            // Rounding the position and ceiling the size is the way that gives better tiled results
+            auto r = FrameSvgHelpers::sectionRect(borders, contentRect, frame->frameSize * q->devicePixelRatio());
+            r.setTopLeft(r.topLeft().toPoint());
+            r.setSize(QSizeF(std::ceil(r.size().width()), std::ceil(r.size().height())));
+
+            p.drawTiledPixmap(r, px);
         }
     }
 }
 
-void FrameSvgPrivate::paintCorner(QPainter &p, const QSharedPointer<FrameData> &frame, KSvg::FrameSvg::EnabledBorders border, const QRect &contentRect) const
+void FrameSvgPrivate::paintCorner(QPainter &p, const QSharedPointer<FrameData> &frame, KSvg::FrameSvg::EnabledBorders border, const QRectF &contentRect) const
 {
+    // contentRect is in device pixels
     // Draw the corner only if both borders in both directions are enabled.
     if ((frame->enabledBorders & border) != border) {
         return;
     }
     const QString corner = frame->prefix % FrameSvgHelpers::borderToElementId(border);
     if (q->hasElement(corner)) {
-        q->paint(&p, FrameSvgHelpers::sectionRect(border, contentRect, frame->frameSize * q->devicePixelRatio()), corner);
+        auto r = FrameSvgHelpers::sectionRect(border, contentRect, frame->frameSize * q->devicePixelRatio());
+        // We are composing QPixmaps here, so all objects with integer size
+        // Rounding the position and ceiling the size is the way that gives better tiled results
+        r.setTopLeft(r.topLeft().toPoint());
+        r.setSize(QSizeF(std::ceil(r.size().width()), std::ceil(r.size().height())));
+        q->paint(&p, r.toRect(), corner);
     }
 }
 
@@ -830,7 +846,7 @@ void FrameSvgPrivate::updateSizes(FrameD
     // qCDebug(LOG_KSVG) << "!!!!!!!!!!!!!!!!!!!!!! updating sizes" << prefix;
     Q_ASSERT(frame);
 
-    QSize s = q->size().toSize();
+    QSizeF s = q->size();
     q->resize();
     if (!frame->cachedBackground.isNull()) {
         frame->cachedBackground = QPixmap();
diff -pruN 6.0.0-1/src/ksvg/private/framesvg_helpers.h 6.3.0-1/src/ksvg/private/framesvg_helpers.h
--- 6.0.0-1/src/ksvg/private/framesvg_helpers.h	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/ksvg/private/framesvg_helpers.h	2024-05-31 13:28:20.000000000 +0000
@@ -45,7 +45,7 @@ QString borderToElementId(FrameSvg::Enab
 /**
  * @returns the suggested geometry for the @p borders given a @p fullSize frame size and a @p contentRect
  */
-QRect sectionRect(KSvg::FrameSvg::EnabledBorders borders, const QRect &contentRect, const QSize &fullSize)
+QRectF sectionRect(KSvg::FrameSvg::EnabledBorders borders, const QRectF &contentRect, const QSizeF &fullSize)
 {
     // don't use QRect corner methods here, they have semantics that might come as unexpected.
     // prefer constructing the points explicitly. e.g. from QRect::topRight docs:
@@ -54,26 +54,26 @@ QRect sectionRect(KSvg::FrameSvg::Enable
     if (borders == FrameSvg::NoBorder) {
         return contentRect;
     } else if (borders == FrameSvg::TopBorder) {
-        return QRect(QPoint(contentRect.left(), 0), QSize(contentRect.width(), contentRect.top()));
+        return QRectF(QPointF(contentRect.left(), 0), QSizeF(contentRect.width(), contentRect.top()));
     } else if (borders == FrameSvg::BottomBorder) {
-        return QRect(QPoint(contentRect.left(), contentRect.bottom() + 1), QSize(contentRect.width(), fullSize.height() - contentRect.bottom() - 1));
+        return QRectF(QPointF(contentRect.left(), contentRect.bottom()), QSizeF(contentRect.width(), fullSize.height() - contentRect.bottom()));
     } else if (borders == FrameSvg::LeftBorder) {
-        return QRect(QPoint(0, contentRect.top()), QSize(contentRect.left(), contentRect.height()));
+        return QRectF(QPointF(0, contentRect.top()), QSizeF(contentRect.left(), contentRect.height()));
     } else if (borders == FrameSvg::RightBorder) {
-        return QRect(QPoint(contentRect.right() + 1, contentRect.top()), QSize(fullSize.width() - contentRect.right() - 1, contentRect.height()));
+        return QRectF(QPointF(contentRect.right(), contentRect.top()), QSizeF(fullSize.width() - contentRect.right(), contentRect.height()));
     } else if (borders == (FrameSvg::TopBorder | FrameSvg::LeftBorder)) {
-        return QRect(QPoint(0, 0), QSize(contentRect.left(), contentRect.top()));
+        return QRectF(QPointF(0, 0), QSizeF(contentRect.left(), contentRect.top()));
     } else if (borders == (FrameSvg::TopBorder | FrameSvg::RightBorder)) {
-        return QRect(QPoint(contentRect.right() + 1, 0), QSize(fullSize.width() - contentRect.right() - 1, contentRect.top()));
+        return QRectF(QPointF(contentRect.right(), 0), QSizeF(fullSize.width() - contentRect.right(), contentRect.top()));
     } else if (borders == (FrameSvg::BottomBorder | FrameSvg::LeftBorder)) {
-        return QRect(QPoint(0, contentRect.bottom() + 1), QSize(contentRect.left(), fullSize.height() - contentRect.bottom() - 1));
+        return QRectF(QPointF(0, contentRect.bottom()), QSizeF(contentRect.left(), fullSize.height() - contentRect.bottom()));
     } else if (borders == (FrameSvg::BottomBorder | FrameSvg::RightBorder)) {
-        return QRect(QPoint(contentRect.right() + 1, contentRect.bottom() + 1),
-                     QSize(fullSize.width() - contentRect.right() - 1, fullSize.height() - contentRect.bottom() - 1));
+        return QRectF(QPointF(contentRect.right(), contentRect.bottom()),
+                      QSizeF(fullSize.width() - contentRect.right(), fullSize.height() - contentRect.bottom()));
     } else {
         qWarning() << "unrecognized border" << borders;
     }
-    return QRect();
+    return QRectF();
 }
 
 }
diff -pruN 6.0.0-1/src/ksvg/private/framesvg_p.h 6.3.0-1/src/ksvg/private/framesvg_p.h
--- 6.0.0-1/src/ksvg/private/framesvg_p.h	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/ksvg/private/framesvg_p.h	2024-05-31 13:28:20.000000000 +0000
@@ -78,38 +78,39 @@ public:
     static const int MAX_CACHED_MASKS = 10;
     uint lastModified = 0;
 
-    QSize frameSize;
+    // Those sizes are in logical pixels
+    QSizeF frameSize;
     uint cacheId;
 
     // measures
-    int topHeight;
-    int leftWidth;
-    int rightWidth;
-    int bottomHeight;
+    qreal topHeight;
+    qreal leftWidth;
+    qreal rightWidth;
+    qreal bottomHeight;
 
     // margins, are equal to the measures by default
-    int topMargin;
-    int leftMargin;
-    int rightMargin;
-    int bottomMargin;
+    qreal topMargin;
+    qreal leftMargin;
+    qreal rightMargin;
+    qreal bottomMargin;
 
     // measures
-    int fixedTopHeight;
-    int fixedLeftWidth;
-    int fixedRightWidth;
-    int fixedBottomHeight;
+    qreal fixedTopHeight;
+    qreal fixedLeftWidth;
+    qreal fixedRightWidth;
+    qreal fixedBottomHeight;
 
     // margins, are equal to the measures by default
-    int fixedTopMargin;
-    int fixedLeftMargin;
-    int fixedRightMargin;
-    int fixedBottomMargin;
-
-    // margins, we only have the hint for insets
-    int insetTopMargin;
-    int insetLeftMargin;
-    int insetRightMargin;
-    int insetBottomMargin;
+    qreal fixedTopMargin;
+    qreal fixedLeftMargin;
+    qreal fixedRightMargin;
+    qreal fixedBottomMargin;
+
+    // margins, we only have the hqreal for insets
+    qreal insetTopMargin;
+    qreal insetLeftMargin;
+    qreal insetRightMargin;
+    qreal insetBottomMargin;
 
     // size of the svg where the size of the "center"
     // element is contentWidth x contentHeight
@@ -158,14 +159,17 @@ public:
         return frameSize(frame.data());
     }
     QSizeF frameSize(FrameData *frame) const;
+
+    // paintBorder, paintCorder and paintCenter sizes are in device pixels
     void paintBorder(QPainter &p,
                      const QSharedPointer<FrameData> &frame,
                      KSvg::FrameSvg::EnabledBorders border,
-                     const QSize &originalSize,
-                     const QRect &output) const;
-    void paintCorner(QPainter &p, const QSharedPointer<FrameData> &frame, KSvg::FrameSvg::EnabledBorders border, const QRect &output) const;
-    void paintCenter(QPainter &p, const QSharedPointer<FrameData> &frame, const QRect &contentRect, const QSize &fullSize);
-    QRect contentGeometry(const QSharedPointer<FrameData> &frame, const QSize &size) const;
+                     const QSizeF &originalSize,
+                     const QRectF &output) const;
+    void paintCorner(QPainter &p, const QSharedPointer<FrameData> &frame, KSvg::FrameSvg::EnabledBorders border, const QRectF &output) const;
+    void paintCenter(QPainter &p, const QSharedPointer<FrameData> &frame, const QRectF &contentRect, const QSizeF &fullSize);
+
+    QRectF contentGeometry(const QSharedPointer<FrameData> &frame, const QSizeF &size) const;
     void updateFrameData(uint lastModified, UpdateType updateType = UpdateFrameAndMargins);
     QSharedPointer<FrameData> lookupOrCreateMaskFrame(const QSharedPointer<FrameData> &frame, const QString &maskPrefix, const QString &maskRequestedPrefix);
 
@@ -177,7 +181,7 @@ public:
 
     FrameSvg *const q;
 
-    QPoint overlayPos;
+    QPointF overlayPos;
 
     QSharedPointer<FrameData> frame;
     QSharedPointer<FrameData> maskFrame;
@@ -185,7 +189,7 @@ public:
     // those can differ from frame->enabledBorders if we are in a transition
     FrameSvg::EnabledBorders enabledBorders;
     // this can differ from frame->frameSize if we are in a transition
-    QSize pendingFrameSize;
+    QSizeF pendingFrameSize;
 
     static QHash<ImageSetPrivate *, QHash<uint, QWeakPointer<FrameData>>> s_sharedFrames;
 
diff -pruN 6.0.0-1/src/ksvg/private/imageset_p.cpp 6.3.0-1/src/ksvg/private/imageset_p.cpp
--- 6.0.0-1/src/ksvg/private/imageset_p.cpp	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/ksvg/private/imageset_p.cpp	2024-05-31 13:28:20.000000000 +0000
@@ -28,9 +28,6 @@
 namespace KSvg
 {
 const char ImageSetPrivate::defaultImageSet[] = "default";
-// the system colors theme is used to cache unthemed svgs with colorization needs
-// these svgs do not follow the theme's colors, but rather the system colors
-const char ImageSetPrivate::systemColorsImageSet[] = "internal-system-colors";
 
 ImageSetPrivate *ImageSetPrivate::globalImageSet = nullptr;
 QHash<QString, ImageSetPrivate *> ImageSetPrivate::themes = QHash<QString, ImageSetPrivate *>();
@@ -136,7 +133,6 @@ bool ImageSetPrivate::useCache()
         if (cacheSize == 0) {
             cacheSize = DEFAULT_CACHE_SIZE;
         }
-        const bool isRegularImageSet = imageSetName != QLatin1String(systemColorsImageSet);
         QString cacheFile = QLatin1String("plasma_theme_") + imageSetName;
 
         // clear any cached values from the previous theme cache
@@ -145,38 +141,37 @@ bool ImageSetPrivate::useCache()
         if (!themeMetadataPath.isEmpty()) {
             KDirWatch::self()->removeFile(themeMetadataPath);
         }
+
         themeMetadataPath = configForImageSet(basePath, imageSetName)->name();
-        if (isRegularImageSet) {
-            const QString cacheFileBase = cacheFile + QLatin1String("*.kcache");
+        const QString cacheFileBase = cacheFile + QLatin1String("*.kcache");
 
-            QString currentCacheFileName;
-            if (!themeMetadataPath.isEmpty()) {
-                // now we record the theme version, if we can
-                const KPluginMetaData data = metaDataForImageSet(basePath, imageSetName);
-                if (data.isValid()) {
-                    themeVersion = data.version();
-                }
-                if (!themeVersion.isEmpty()) {
-                    cacheFile += QLatin1String("_v") + themeVersion;
-                    currentCacheFileName = cacheFile + QLatin1String(".kcache");
-                }
+        QString currentCacheFileName;
+        if (!themeMetadataPath.isEmpty()) {
+            // now we record the theme version, if we can
+            const KPluginMetaData data = metaDataForImageSet(basePath, imageSetName);
+            if (data.isValid()) {
+                themeVersion = data.version();
+            }
+            if (!themeVersion.isEmpty()) {
+                cacheFile += QLatin1String("_v") + themeVersion;
+                currentCacheFileName = cacheFile + QLatin1String(".kcache");
             }
+        }
 
-            // now we check for, and remove if necessary, old caches
-            QDir cacheDir(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation));
-            cacheDir.setNameFilters(QStringList({cacheFileBase}));
-
-            const auto files = cacheDir.entryInfoList();
-            for (const QFileInfo &file : files) {
-                if (currentCacheFileName.isEmpty() //
-                    || !file.absoluteFilePath().endsWith(currentCacheFileName)) {
-                    QFile::remove(file.absoluteFilePath());
-                }
+        // now we check for, and remove if necessary, old caches
+        QDir cacheDir(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation));
+        cacheDir.setNameFilters(QStringList({cacheFileBase}));
+
+        const auto files = cacheDir.entryInfoList();
+        for (const QFileInfo &file : files) {
+            if (currentCacheFileName.isEmpty() //
+                || !file.absoluteFilePath().endsWith(currentCacheFileName)) {
+                QFile::remove(file.absoluteFilePath());
             }
         }
 
         // now we do a sanity check: if the metadata.desktop file is newer than the cache, drop the cache
-        if (isRegularImageSet && !themeMetadataPath.isEmpty()) {
+        if (!themeMetadataPath.isEmpty()) {
             // now we check to see if the theme metadata file itself is newer than the pixmap cache
             // this is done before creating the pixmapCache object since that can change the mtime
             // on the cache file
@@ -660,19 +655,14 @@ void ImageSetPrivate::setImageSetName(co
         }
     }
 
-    // we have one special theme: essentially a dummy theme used to cache things with
-    // the system colors.
-    bool realImageSet = theme != QLatin1String(systemColorsImageSet);
-    if (realImageSet) {
-        KPluginMetaData data = metaDataForImageSet(basePath, theme);
+    KPluginMetaData data = metaDataForImageSet(basePath, theme);
+    if (!data.isValid()) {
+        data = metaDataForImageSet(basePath, QStringLiteral("default"));
         if (!data.isValid()) {
-            data = metaDataForImageSet(basePath, QStringLiteral("default"));
-            if (!data.isValid()) {
-                return;
-            }
-
-            theme = QLatin1String(ImageSetPrivate::defaultImageSet);
+            return;
         }
+
+        theme = QLatin1String(ImageSetPrivate::defaultImageSet);
     }
 
     // check again as ImageSetPrivate::defaultImageSet might be empty
@@ -683,8 +673,7 @@ void ImageSetPrivate::setImageSetName(co
     imageSetName = theme;
 
     // load the color scheme config
-    const QString colorsFile =
-        realImageSet ? QStandardPaths::locate(QStandardPaths::GenericDataLocation, basePath % theme % QLatin1String("/colors")) : QString();
+    const QString colorsFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, basePath % theme % QLatin1String("/colors"));
     // qCDebug(LOG_KSVG) << "we're going for..." << colorsFile << "*******************";
 
     if (colorsFile.isEmpty()) {
@@ -701,43 +690,41 @@ void ImageSetPrivate::setImageSetName(co
     headerColorScheme = KColorScheme(QPalette::Active, KColorScheme::Header, colors);
     tooltipColorScheme = KColorScheme(QPalette::Active, KColorScheme::Tooltip, colors);
 
-    if (realImageSet) {
-        pluginMetaData = metaDataForImageSet(basePath, theme);
-        KSharedConfigPtr metadata = configForImageSet(basePath, theme);
+    pluginMetaData = metaDataForImageSet(basePath, theme);
+    KSharedConfigPtr metadata = configForImageSet(basePath, theme);
 
+    KConfigGroup cg(metadata, QStringLiteral("Settings"));
+    QString fallback = cg.readEntry("FallbackImageSet", QString());
+
+    fallbackImageSets.clear();
+    while (!fallback.isEmpty() && !fallbackImageSets.contains(fallback)) {
+        fallbackImageSets.append(fallback);
+
+        KSharedConfigPtr metadata = configForImageSet(basePath, fallback);
         KConfigGroup cg(metadata, QStringLiteral("Settings"));
-        QString fallback = cg.readEntry("FallbackImageSet", QString());
+        fallback = cg.readEntry("FallbackImageSet", QString());
+    }
 
-        fallbackImageSets.clear();
-        while (!fallback.isEmpty() && !fallbackImageSets.contains(fallback)) {
-            fallbackImageSets.append(fallback);
-
-            KSharedConfigPtr metadata = configForImageSet(basePath, fallback);
-            KConfigGroup cg(metadata, QStringLiteral("Settings"));
-            fallback = cg.readEntry("FallbackImageSet", QString());
-        }
-
-        if (!fallbackImageSets.contains(QLatin1String(ImageSetPrivate::defaultImageSet))) {
-            fallbackImageSets.append(QLatin1String(ImageSetPrivate::defaultImageSet));
-        }
-
-        // Check for what Plasma version the theme has been done
-        // There are some behavioral differences between KDE4 Plasma and Plasma 5
-        const QString apiVersion = pluginMetaData.value(QStringLiteral("X-Plasma-API"));
-        apiMajor = 1;
-        apiMinor = 0;
-        apiRevision = 0;
-        if (!apiVersion.isEmpty()) {
-            const QList<QStringView> parts = QStringView(apiVersion).split(QLatin1Char('.'));
-            if (!parts.isEmpty()) {
-                apiMajor = parts.value(0).toInt();
-            }
-            if (parts.count() > 1) {
-                apiMinor = parts.value(1).toInt();
-            }
-            if (parts.count() > 2) {
-                apiRevision = parts.value(2).toInt();
-            }
+    if (!fallbackImageSets.contains(QLatin1String(ImageSetPrivate::defaultImageSet))) {
+        fallbackImageSets.append(QLatin1String(ImageSetPrivate::defaultImageSet));
+    }
+
+    // Check for what Plasma version the theme has been done
+    // There are some behavioral differences between KDE4 Plasma and Plasma 5
+    const QString apiVersion = pluginMetaData.value(QStringLiteral("X-Plasma-API"));
+    apiMajor = 1;
+    apiMinor = 0;
+    apiRevision = 0;
+    if (!apiVersion.isEmpty()) {
+        const QList<QStringView> parts = QStringView(apiVersion).split(QLatin1Char('.'));
+        if (!parts.isEmpty()) {
+            apiMajor = parts.value(0).toInt();
+        }
+        if (parts.count() > 1) {
+            apiMinor = parts.value(1).toInt();
+        }
+        if (parts.count() > 2) {
+            apiRevision = parts.value(2).toInt();
         }
     }
 
diff -pruN 6.0.0-1/src/ksvg/private/imageset_p.h 6.3.0-1/src/ksvg/private/imageset_p.h
--- 6.0.0-1/src/ksvg/private/imageset_p.h	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/ksvg/private/imageset_p.h	2024-05-31 13:28:20.000000000 +0000
@@ -113,7 +113,6 @@ public:
     bool eventFilter(QObject *watched, QEvent *event) override;
 
     static const char defaultImageSet[];
-    static const char systemColorsImageSet[];
     static const char themeRcFile[];
 
     // Ref counting of ImageSetPrivate instances
diff -pruN 6.0.0-1/src/ksvg/private/svg_p.h 6.3.0-1/src/ksvg/private/svg_p.h
--- 6.0.0-1/src/ksvg/private/svg_p.h	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/ksvg/private/svg_p.h	2024-05-31 13:28:20.000000000 +0000
@@ -72,7 +72,6 @@ public:
     bool setImagePath(const QString &imagePath);
 
     ImageSet *actualImageSet();
-    ImageSet *cacheAndColorsImageSet();
 
     QPixmap findInCache(const QString &elementId, qreal ratio, const QSizeF &s = QSizeF());
 
@@ -139,8 +138,8 @@ public:
     void setNaturalSize(const QString &path, const QSizeF &size);
     QSizeF naturalSize(const QString &path);
 
-    QList<QSize> sizeHintsForId(const QString &path, const QString &id);
-    void insertSizeHintForId(const QString &path, const QString &id, const QSize &size);
+    QList<QSizeF> sizeHintsForId(const QString &path, const QString &id);
+    void insertSizeHintForId(const QString &path, const QString &id, const QSizeF &size);
 
     QString iconThemePath();
     void setIconThemePath(const QString &path);
@@ -167,7 +166,7 @@ private:
      */
     QHash<size_t, QRectF> m_localRectCache;
     QHash<QString, QSet<unsigned int>> m_invalidElements;
-    QHash<QString, QList<QSize>> m_sizeHintsForId;
+    QHash<QString, QList<QSizeF>> m_sizeHintsForId;
     QHash<QString, unsigned int> m_lastModifiedTimes;
 };
 }
diff -pruN 6.0.0-1/src/ksvg/svg.cpp 6.3.0-1/src/ksvg/svg.cpp
--- 6.0.0-1/src/ksvg/svg.cpp	2024-02-21 11:27:13.000000000 +0000
+++ 6.3.0-1/src/ksvg/svg.cpp	2024-05-31 13:28:20.000000000 +0000
@@ -272,7 +272,7 @@ void SvgRectsCache::dropImageFromCache(c
     QMetaObject::invokeMethod(m_configSyncTimer, qOverload<>(&QTimer::start));
 }
 
-QList<QSize> SvgRectsCache::sizeHintsForId(const QString &path, const QString &id)
+QList<QSizeF> SvgRectsCache::sizeHintsForId(const QString &path, const QString &id)
 {
     const QString pathId = path % id;
 
@@ -280,7 +280,7 @@ QList<QSize> SvgRectsCache::sizeHintsFor
     if (it == m_sizeHintsForId.constEnd()) {
         KConfigGroup imageGroup(m_svgElementsCache, path);
         const QStringList &encoded = imageGroup.readEntry(id, QStringList());
-        QList<QSize> sizes;
+        QList<QSizeF> sizes;
         for (const auto &token : encoded) {
             const auto &parts = token.split(QLatin1Char('x'));
             if (parts.size() != 2) {
@@ -298,10 +298,10 @@ QList<QSize> SvgRectsCache::sizeHintsFor
     return *it;
 }
 
-void SvgRectsCache::insertSizeHintForId(const QString &path, const QString &id, const QSize &size)
+void SvgRectsCache::insertSizeHintForId(const QString &path, const QString &id, const QSizeF &size)
 {
     // TODO: need to make this more efficient
-    auto sizeListToString = [](const QList<QSize> &list) {
+    auto sizeListToString = [](const QList<QSizeF> &list) {
         QString ret;
         for (const auto &s : list) {
             ret += QString::number(s.width()) % QLatin1Char('x') % QString::number(s.height()) % QLatin1Char(',');
@@ -449,12 +449,21 @@ QString SvgPrivate::cachePath(const QStr
 bool SvgPrivate::setImagePath(const QString &imagePath)
 {
     QString actualPath = imagePath;
+    bool isAbsoluteFile = QDir::isAbsolutePath(actualPath);
     if (imagePath.startsWith(QLatin1String("file://"))) {
         // length of file://
         actualPath.remove(0, 7);
+        isAbsoluteFile = true;
+    }
+    // If someone using the QML API uses Qt.resolvedUrl to get the absolute path inside of a QRC,
+    // the URI will look something like qrc:/artwork/file.svg
+    // In order for file IO to work it needs to be reformatted it needs to be :/artwork/file.svg
+    if (imagePath.startsWith(QLatin1String("qrc:/"))) {
+        actualPath.replace(QLatin1String("qrc:/"), QLatin1String(":/"));
+        isAbsoluteFile = true;
     }
 
-    bool isThemed = !actualPath.isEmpty() && !QDir::isAbsolutePath(actualPath);
+    bool isThemed = !actualPath.isEmpty() && !isAbsoluteFile;
 
     // lets check to see if we're already set to this file
     if (isThemed == themed && ((themed && themePath == actualPath) || (!themed && path == actualPath))) {
@@ -468,11 +477,6 @@ bool SvgPrivate::setImagePath(const QStr
     bool updateNeeded = true; //! path.isEmpty() || !themePath.isEmpty();
 
     QObject::disconnect(imageSetChangedConnection);
-    if (isThemed && !themed && s_systemColorsCache) {
-        // catch the case where we weren't themed, but now we are, and the colors cache was set up
-        // ensure we are not connected to that theme previously
-        QObject::disconnect(s_systemColorsCache.data(), nullptr, q, nullptr);
-    }
 
     themed = isThemed;
     path.clear();
@@ -549,21 +553,6 @@ ImageSet *SvgPrivate::actualImageSet()
     return theme.data();
 }
 
-ImageSet *SvgPrivate::cacheAndColorsImageSet()
-{
-    if (themed) {
-        return actualImageSet();
-    } else {
-        // use a separate cache source for unthemed svg's
-        if (!s_systemColorsCache) {
-            // FIXME: reference count this, so that it is deleted when no longer in use
-            s_systemColorsCache = new KSvg::ImageSet(QStringLiteral("internal-system-colors"));
-        }
-
-        return s_systemColorsCache.data();
-    }
-}
-
 QPixmap SvgPrivate::findInCache(const QString &elementId, qreal ratio, const QSizeF &s)
 {
     QSize size;
@@ -572,7 +561,7 @@ QPixmap SvgPrivate::findInCache(const QS
     // Look at the size hinted elements and try to find the smallest one with an
     // identical aspect ratio.
     if (s.isValid() && !elementId.isEmpty()) {
-        const QList<QSize> elementSizeHints = SvgRectsCache::instance()->sizeHintsForId(path, elementId);
+        const QList<QSizeF> elementSizeHints = SvgRectsCache::instance()->sizeHintsForId(path, elementId);
 
         if (!elementSizeHints.isEmpty()) {
             QSizeF bestFit(-1, -1);
@@ -607,8 +596,7 @@ QPixmap SvgPrivate::findInCache(const QS
     const QString id = cachePath(actualElementId, size);
 
     QPixmap p;
-    if (cacheRendering && lastModified == SvgRectsCache::instance()->lastModifiedTimeFromCache(path)
-        && cacheAndColorsImageSet()->d->findInCache(id, p, lastModified)) {
+    if (cacheRendering && lastModified == SvgRectsCache::instance()->lastModifiedTimeFromCache(path) && actualImageSet()->d->findInCache(id, p, lastModified)) {
         p.setDevicePixelRatio(ratio);
         // qCDebug(LOG_PLASMA) << "found cached version of " << id << p.size();
         return p;
@@ -635,7 +623,7 @@ QPixmap SvgPrivate::findInCache(const QS
     p.setDevicePixelRatio(ratio);
 
     if (cacheRendering) {
-        cacheAndColorsImageSet()->d->insertIntoCache(id, p, QString::number((qint64)q, 16) % QLatin1Char('_') % actualElementId);
+        actualImageSet()->d->insertIntoCache(id, p, QString::number((qint64)q, 16) % QLatin1Char('_') % actualElementId);
     }
 
     SvgRectsCache::instance()->updateLastModified(path, lastModified);
@@ -662,11 +650,11 @@ void SvgPrivate::createRenderer()
     QString styleSheet;
     if (!colorOverrides.isEmpty()) {
         if (stylesheetOverride.isEmpty()) {
-            stylesheetOverride = cacheAndColorsImageSet()->d->svgStyleSheet(q);
+            stylesheetOverride = actualImageSet()->d->svgStyleSheet(q);
         }
         styleSheet = stylesheetOverride;
     } else {
-        styleSheet = cacheAndColorsImageSet()->d->svgStyleSheet(q);
+        styleSheet = actualImageSet()->d->svgStyleSheet(q);
     }
 
     styleCrc = qChecksum(QByteArrayView(styleSheet.toUtf8().constData(), styleSheet.size()));
@@ -885,18 +873,11 @@ Svg::~Svg()
 
 void Svg::setDevicePixelRatio(qreal ratio)
 {
-    // be completely integer for now
-    // devicepixelratio is always set integer in the svg, so needs at least 192dpi to double up.
-    //(it needs to be integer to have lines contained inside a svg piece to keep being pixel aligned)
-    if (floor(d->devicePixelRatio) == floor(ratio)) {
-        return;
-    }
-
     if (FrameSvg *f = qobject_cast<FrameSvg *>(this)) {
         f->clearCache();
     }
 
-    d->devicePixelRatio = floor(ratio);
+    d->devicePixelRatio = ratio;
 
     Q_EMIT repaintNeeded();
 }
@@ -924,7 +905,7 @@ QImage Svg::image(const QSize &size, con
 void Svg::paint(QPainter *painter, const QPointF &point, const QString &elementID)
 {
     Q_ASSERT(painter->device());
-    const int ratio = painter->device()->devicePixelRatio();
+    const qreal ratio = painter->device()->devicePixelRatio();
     QPixmap pix((elementID.isNull() || d->multipleImages) ? d->findInCache(elementID, ratio, size()) : d->findInCache(elementID, ratio));
 
     if (pix.isNull()) {
@@ -942,16 +923,16 @@ void Svg::paint(QPainter *painter, int x
 void Svg::paint(QPainter *painter, const QRectF &rect, const QString &elementID)
 {
     Q_ASSERT(painter->device());
-    const int ratio = painter->device()->devicePixelRatio();
+    const qreal ratio = painter->device()->devicePixelRatio();
     QPixmap pix(d->findInCache(elementID, ratio, rect.size()));
 
-    painter->drawPixmap(QRectF(rect.topLeft(), rect.size()), pix, QRectF(QPointF(0, 0), pix.size()));
+    painter->drawPixmap(rect, pix, QRect(QPoint(0, 0), pix.size()));
 }
 
 void Svg::paint(QPainter *painter, int x, int y, int width, int height, const QString &elementID)
 {
     Q_ASSERT(painter->device());
-    const int ratio = painter->device()->devicePixelRatio();
+    const qreal ratio = painter->device()->devicePixelRatio();
     QPixmap pix(d->findInCache(elementID, ratio, QSizeF(width, height)));
     painter->drawPixmap(x, y, pix, 0, 0, pix.size().width(), pix.size().height());
 }
@@ -1144,7 +1125,7 @@ QColor Svg::color(StyleSheetColor colorN
     if (it != d->colorOverrides.constEnd()) {
         return *it;
     }
-    return d->cacheAndColorsImageSet()->d->namedColor(colorName, this);
+    return d->actualImageSet()->d->namedColor(colorName, this);
 }
 
 void Svg::setColor(StyleSheetColor colorName, const QColor &color)
